/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_CHAFFVERB_HPP_
#define _HEAVY_CONTEXT_CHAFFVERB_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvSignalLine.h"
#include "HvSignalTabwrite.h"
#include "HvControlSlice.h"
#include "HvSignalVar.h"
#include "HvControlCast.h"
#include "HvSignalPhasor.h"
#include "HvControlIf.h"
#include "HvMath.h"
#include "HvControlDelay.h"
#include "HvControlPack.h"
#include "HvControlSystem.h"
#include "HvControlVar.h"
#include "HvControlBinop.h"
#include "HvSignalTabread.h"
#include "HvControlUnop.h"
#include "HvSignalDel1.h"
#include "HvControlRandom.h"
#include "HvControlTabhead.h"
#include "HvTable.h"
#include "HvSignalRPole.h"

class Heavy_ChaffVerb : public HeavyContext {

 public:
  Heavy_ChaffVerb(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_ChaffVerb();

  const char *getName() override { return "ChaffVerb"; }
  int getNumInputChannels() override { return 1; }
  int getNumOutputChannels() override { return 2; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        A__LFO_PERIOD = 0x1F30993F, // A__LFO_Period
        A__LFO_STEPS_SCALE__TYPE2 = 0x1A2B8E9F, // A__LFO_Steps_Scale__Type2
        A__LFO_STEPS__TYPE2 = 0xBE3344C8, // A__LFO_Steps__Type2
        A__LFO_SWITCH = 0x7369936E, // A__LFO_Switch
        A__LFO_TYPE = 0xD64CFD23, // A__LFO_type
        B__GENERAL_OFFSET = 0x51447E19, // B__General_Offset
        B__GENERAL_SCALE = 0xA10FCFC4, // B__General_Scale
        C__RANDOM_LFO_OFFSET = 0x7EFB8E46, // C__Random_LFO_Offset
        C__RANDOM_LFO_PERIOD = 0xE6223016, // C__Random_LFO_Period
        C__RANDOM_LFO_SCALE = 0x3281900D, // C__Random_LFO_Scale
        C__RANDOM_LFO_SWITCH = 0x6150BC53, // C__Random_LFO_Switch
        D__SHIFT_MICROTONE = 0x9CBB1BF3, // D__Shift_Microtone
        D__SHIFT_TRANSPOSE = 0x4439D71, // D__Shift_Transpose
        E__FX_LEVEL = 0x890283C2, // E__Fx_Level
        E__HIPASS_FREQ = 0x12962685, // E__HiPass_Freq
        E__SHIFT_DELAY = 0x183CFEE5, // E__Shift_Delay
        E__SHIFT_WINDOW = 0x57FF40DB, // E__Shift_Window
        F__FX_DELAY = 0x69A91334, // F__FX_Delay
        F__FX_DELAY_FEEDBACK = 0x68D029F7, // F__FX_Delay_Feedback
        MIX__DRY_MIX = 0xD63693D0, // Mix__Dry_Mix
        MIX__DRY_VOL = 0x1FC3C02C, // Mix__Dry_Vol
        MIX__REVERB_LEVEL = 0x58653D84, // Mix__Reverb_Level
        MIX__REVERB_VOL = 0xE764F673, // Mix__Reverb_Vol
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void cVar_ODdHrkvx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_xefN2xWb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_2lPZ8NRy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_ozplKQkS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jaySaagz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_m3EKAMP3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_QyyUEuBk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_aNZ5WOMY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_mUMjOq9C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kMeJbgVr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_CIwYMqHx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_R0AGFgkJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_KM58s7HG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_fKYpes2Y_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_osuFk77G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_DYaSlRhE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_X0uDP7Jy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Hvwa3q3i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QIH6Pwp6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_VA1HK4mZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Uf2era6k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_uMKFuozN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nBDibG1z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_kLKXpP0G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_PKCpMu1q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_pHxEUnZn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_p8hnuevD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_o6LfQrCv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zA9nVotb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7ZHOAvsJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_87qPGwik_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_kfCPvAJ6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_FdWea3xN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7grBmygo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JYSvy8FX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_y4Gny330_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PjSJ8lha_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QJlua14o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_XPJbWSir_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_mLzGq9vd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BSOnoEiy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Im9XaTdK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mI9VSfmU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0oLIqXDl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1SuOvjzj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_HWqVJgI6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_zZCwqSRV_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_Qzq5r47a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_wSM6SgXA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0YolKjII_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3phDTLVj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lhrRNYOn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_jKakNvpE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Aejd6rNt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_0NbQNj1g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vA5cqOH0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gaAPTlsn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WMMswPXT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jNhnnA2H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gaehlu8B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cP1D4OO9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6OWDcR5C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8c45Pavk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_3Uv6Fd8p_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_Pyj37rxY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_Nym7pZnr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cRandom_ZdaxPfGj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_NO5cRZLt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_Tcoz9cTr_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_hh1XRNom_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_TLdtHPIk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5VbXoVqO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_b4L0Nkf8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_PIbvHXd6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vSXwdg7D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_P2IIN5Y6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VuOqOlSQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_F7IEMl5K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_RyvU3PWU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0P5vgpcP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_EJO9vYMV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_mo2tx1bc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_tANuq7nv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_Y14zDpbB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_7WDI4aPT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WW6EYeT6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2gGgcCnB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QKiI0lXT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_hWPRxikF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1TskSZY8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_pmTP0Iiy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_js9ocMJ9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_unSoMnmn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_m3ZBCCgP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_emwTLRkT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wVosukry_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_y5ixSXe0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_zSf3h4nV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rAC3e481_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_wU9Rjicz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_0mzy8eyX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_9Pr7Ek75_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_h5VUqwyU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_gnHu58Jr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9t3WLXc7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_z65MOAwy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ngbybU9Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_YzBMarQ7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SV57oNHS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FSKiNJhp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bTVrJWjP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4m26YLAm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_J5kMFcaC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SodMJ3yV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VQMZqIW9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_OPjRIjz6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_vf8MpW5m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GYMUQXhZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_moMBXc3X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_69EXG7nV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_mcJreT0g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_q4EyuiUV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_ahU3pB3H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AIQf7Yog_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_25RvDVAh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XAvvCIcu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_IqnONscG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ucG4NQD0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jwrLRfLM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DesWvglX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_J66uIDKs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ulIpByH3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ATbNID9k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uD7FpctD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LyaKhQMp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_5US86sJf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UOcZqbQ5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_hxVsI4jo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_8HGBrpHJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_3rq7jeOh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_Vlmo2uCI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_yqQ1pdWX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vti4IXZx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1433xGbf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BhevXLae_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_Kf98KrFl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gzRXyJF6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_V8wfYImk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_y8f3BIVC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QSDg3Br6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_NftGwHIw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MQMBsB86_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MsCyD43p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_4x7aoK4F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nEKxjg0E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_O2lsDxPf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_NCPv6bNF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_d1rLeWNE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_IVaEtVmB_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_Z0DpcWeG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_NyaIKUQ5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7KriPh05_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mwECx5Ri_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CVkPdaSh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_3adVwEPz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_TlpisHxN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_M1DsGnOj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_A5Xq5rVo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_mKUKIJ8B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_dx1msDw6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_dspepbfs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_9mv8gZpM_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_TNErpEws_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_TaWDj5vU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_z6i7R8n4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XHaKGXgM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_L3mJ0OFi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_hrJHuUbS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_W4u6QXEb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_TpSbmrku_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MeztCBe7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_hjiRaiSa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_fpffzd1Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_WlUfMvGQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_XWszj0vq_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_16OjkEsf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_fiQE0RI9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bHesDRxt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nypV30ro_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_U4a9Fyxl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7w7al49x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hU4CVmr9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_TxMCk2nh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_eX4RuWyx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_S2TsBeuA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_ZWiuDD3z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_uU8dmnaQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_n9pfLqKV_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_fjRPTOkO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_IN7rXJDL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Ym2E62CX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XCVRBpPh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hUEjhShc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_uiuCM59r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_M3svxXXh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zpaHsUfr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_fGt1YB7V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_p7zoaMGB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_R9kZxlyu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8VRF0PXU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_fXgFpsF0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qiX0MTKJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_PLtnZ0NI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vsjCPcsV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Wjsuyo9Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_v81Ap0tl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_b7pb31ER_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YmlnAKch_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AumYwmke_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_oHnXd3cT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_1eWsxQMS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_YCMr5MlE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_oFdrLCII_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_7rVdvtEL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_f0BvQ0cr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ulY4nDMa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kw6fgnQ1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5mTy0jtd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_Q01c1J1g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_RQGpujiK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_lsUvLvH5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_WqmOdgx9_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_6XCdT3Nk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_bqTOuW1T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FnW8Vmlm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UkvSUk4n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QfVlNivs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ooY0lGvQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_pvc0xn2L_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mIDNAfbG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_vZBCvVpQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mzR6UhGa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_VAN1BpLR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_SVESKeA9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_KSGWjcsZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_qb3xAJ8Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_5vBrt5Lt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_awaRR0nD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_eRYlguxa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7ltIfhPY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_YiL2K4jf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cKH6vio6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HNwmL3mH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0QI0Hm3F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QsKJCxh9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_VWMplb6T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NydIxXys_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7DiKtxrs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_4ODLDtNQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_d17bD3vA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_g0XbUpo1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_fbi0B0Rm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_bpEKovGk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_YdxmaaiC_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_F0FYCCPI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_r3HfJ7py_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4D9DdYKd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_H8zhJ6Au_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Ee5bAFqc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_OveIYYWw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Y3OhEuzt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rD3YMsOK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_InAl9VQU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_r4UnVSPQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_mTxKAFNt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_pKC0yOrJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_1P2N4euC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_BlrgKH5W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_1Kl3wrmP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_147p8vxa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_okAmcYku_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZoSNL2cD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_3ouGvdjy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_STctAfcE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8XwmKgKG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CCWFnRev_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GsOvjG74_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_79NQx7tE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xHgsX0eh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7yfIhw8I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_3B48hbU1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dth16pqW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_dvc1U895_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_gDTCkO7J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_01d4wnzX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_s0T6mWJd_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_ApRGEhtz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_WsrASp2G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Qcs6OTOR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RnkMpjD8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ylFWaZcJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_O15LUF2a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dlTpAP74_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6shmyWmg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_8W3uz42X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bLOhHLEk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_SgHMrHGu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_y7ej96da_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_pOqwfQJx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_9llx5H16_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_cLcPVf2T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TzDSvkz4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sHEf5Dti_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7N5gIPIH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_2inrRmhr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hm3h4owI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_V67kaAyb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_RnDDQVCT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tZ30gduz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_CrnpEosf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WeajDe2r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_is2HBZhF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_DjGRS027_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mCRTHbrl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_5Ad9OzUe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_cv7vDQxw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_TPHicpsP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_LvsAZxv0_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_D9V8Elwk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_giTLcA7T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tKZKAusT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Cs25OqnJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jC2Qh6ox_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_EzY11VTx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UF7rC9le_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hv4oBJtn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_ENmo1egN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Yzu20T5y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_SdzQWMWD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_x8ezLMxf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_Ncr2tMQH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_zyJyZv6e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_RbvJeJAQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gmQB5WDs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WiU9zmIi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tvDWHSJu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_n0DdVSjc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xJKiF2Mo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ex7c5EQY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rj7NI2Ao_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mRapKcO2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_IJQSbiC0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_evhhOGQP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_m2kFOFkK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_q9BNHCFg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wPfBIMO5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_gb6y40FJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_tCCXrmvP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_SNfCdIUL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_zjtj0cCt_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_bSRFVHWX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_q2orfTlk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_d1kgX8aD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_axDvTGal_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_de3YdDjh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ed4lZA4L_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6uXymsdb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QmeTf5w5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_8pBGksOt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vNcG6shs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_ldUj79bM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_eHFgmnPJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_OM2ZTRfz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_rsbZTNnt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_18WxEltQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_r2pBmShc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bAGnyWVJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tCHPttmq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_oXpIXfUl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_RXCKO0DI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_euG40Cbh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gPMDto43_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RQ8AuKyl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_DXUi8pvU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8iIixZTF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VahIToIg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_nHHoKq9o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jUDOk34I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_1HfhMS8K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_jGZDHNcM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_HpuALlgz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_l93prFrD_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_q5v6X8s0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_qBB091qh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3ESl0G20_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_n2zxn9mG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vozL0Yqr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ijPZnTf7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_S3pOMG1G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dT03uWvU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_7iCibBZR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SANNuDx6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_YcTGFcwA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_NRBGibz3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_HhnCKYkD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_e3Osx1DX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_8xYydRsB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BYKvi91d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WzseURxv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hrmhortT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_fmjS5hX1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_diiwCaJT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DoFGoz10_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_21TBb4XE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WnCx3UwD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ocWD3zf9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8VqzBlV3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WRhWegqg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_PgdjgLnF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_DUmfrq7l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_KakEh7GG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_Ecxd4Btu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_I0S6g0Uv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6C5P5xCG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_ZymPdGan_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TPMIZzat_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wpmLQ66b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cjV4fTpX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7asygAML_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ofa3lR5W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PWHVUhum_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_WhJY5Ixy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_AgV4N6ss_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_qV4scaHV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ynBwZ9kq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_o7cLdUUo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9EBVuWAa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_n67iGy0F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SONt1JdT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Dw6wCyPV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_443M7CYE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_v6M8SRTy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_VCmgDJjX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tyH9SQr1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7QEedLZC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WAT2rw6G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gLx4zd3K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0Kfz8Yab_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0XvY5e2o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3WyssFfY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zXqbnH9g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XgKgFAH9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_s7raUbIz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_bVCvX3jb_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_PytoHoQl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_09o7bRE1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MtJ556oz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_Sjub8A7U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_485SeXnK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_TAHUgd8D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4FCgomZ8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_R36tzG9x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JYhN4ggm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_YX8v9oc9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_kry5TWIQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_UeQhSCoe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_Q7kEbitY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_trJmItzA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xL8F6CSC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_doDkCyKy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_s30ZJBnu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_hU4llCfj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_4vJKZcYf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_G5xmjrRS_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_rXNsuM2R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_L7NJBGh6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_U4UQJChk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0k3G5vMS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CXrCaJE9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_iv27HzTc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5Ua3kl03_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JJLp2vYR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_ORVbPI8R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ihbDag0L_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_Nawmi6zL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_7OCxbr6W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_pEeHxv08_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_FpqaTGLC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_B4m31igs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zh5WTNM6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GrAJSgMd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qDzC6Krq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_kAKt8Diy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cf4QxIdb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NM1r7aSk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hqS1yMdV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HjPKrX3s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0l7PpWNS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_o0CfbAvY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_b5P4Ts8H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ZgmWcJdu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_tDMwIUUD_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_vPr8ukoN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_X83T25BI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_Es0BJF1C_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_kfuKpzkF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_sRuotCL2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_IdRgGlRI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_k1paVRUq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Q7PM3wci_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_6Iemn6Eg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_MdNwQ2hg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_aEZ4X5r6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_eO2pemkq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CMDkMiDP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Z4iHosQS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_qXq8zmJU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_O3az2NHy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_qGNxcImY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_45f1Jn7a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_3aYMi7xj_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_MliDOj2o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_mmI4o2q2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_XvKnZ57B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_ozGrrXCJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ow1lb5IY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_78rP002x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yLSXdD7y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_izrbMMxX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_fUil099c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_JpYoQq4j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_8fUIzGTP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_Mr1CnmgC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_IoVsv4au_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_biX90F8G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8vYIfa9T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_uhGsp3iS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WuzidbFT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_YBM00PNN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ALJgt6ZO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uewWTS4x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GDIld0MK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5jsqlO45_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_eqtUJfKh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_X8DgBo2I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DbC5XjBe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LRITNHXs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1klMG5XJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_TZMHz2p8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_i1q4hBb7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_iayNteuh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VTLhVkPR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_X3uy4Ndk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DaI1qNjE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qnsdXAqn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IqgiXDWp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HJq4D2QH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QBG7lttO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_u9mfNsck_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rHV1HAsm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rMll3i7d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_atyEqK7y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DzqH979z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fAyPuy9P_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_M1h1VBfE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HfoP4l8b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Ii54qSf5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_z2S3mScA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_FpQhaDOV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_TMrwG9de_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_eB7TSKfs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_eg1neooh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_4wh2I2c8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_fimQLYPK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uXtukGZ5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WeSqvwLv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_RK6xBttC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0Pf3STwn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7pqAWpju_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_XCuPz071_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DzvyO2Xr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_GMfRmNf2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_x4w58j7N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Yq18nDfq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_66BxQk6g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_EhJQp0f0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_WVF18ach_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_xXFBhsqU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_qOout72y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_WQaP177n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_mMpD8sR2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_tYZtLglG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_86arlxyv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Jn3t7dGT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_GfgBm8zT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Qht5EUN4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_XIR4osph_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_2U88Decy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_gEFiBOlR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_l5kzDwJD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_qUoUOHPz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_kZFs9edU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_m65WsHUJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_O94JcZ2g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_R27U671w_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalPhasor sPhasor_afzQn89y;
  SignalLine sLine_Kkad90Ga;
  SignalLine sLine_t9TMQyqE;
  SignalTabhead sTabhead_4pkvc85T;
  SignalTabread sTabread_VeSwpv8V;
  SignalTabread sTabread_iQtvS8pZ;
  SignalTabhead sTabhead_ekQ8ud6x;
  SignalTabread sTabread_LSTIa4QR;
  SignalTabread sTabread_q3rxNhgH;
  SignalTabwrite sTabwrite_QRkkhrJc;
  SignalRPole sRPole_8t6iTKa4;
  SignalDel1 sDel1_jut503ns;
  SignalTabread sTabread_B4m31igs;
  SignalTabwrite sTabwrite_azEBcTCe;
  SignalTabread sTabread_7WDI4aPT;
  SignalRPole sRPole_fNTUQ2jn;
  SignalLine sLine_xbzsq2FY;
  SignalLine sLine_B8tHs58F;
  SignalTabread sTabread_5vBrt5Lt;
  SignalTabread sTabread_1Kl3wrmP;
  SignalTabread sTabread_cLcPVf2T;
  SignalTabread sTabread_RbvJeJAQ;
  SignalTabread sTabread_8xYydRsB;
  SignalTabread sTabread_18WxEltQ;
  SignalTabwrite sTabwrite_bQeLtBe0;
  SignalTabwrite sTabwrite_G4XvBQ0b;
  SignalTabwrite sTabwrite_WHZaySni;
  SignalTabwrite sTabwrite_S9UN3mKO;
  SignalTabwrite sTabwrite_4QFm9txG;
  SignalTabwrite sTabwrite_ePBn4bHE;
  SignalTabread sTabread_gnHu58Jr;
  SignalRPole sRPole_i9JFecmT;
  SignalTabread sTabread_ahU3pB3H;
  SignalRPole sRPole_73OZHrfu;
  SignalTabread sTabread_yqQ1pdWX;
  SignalRPole sRPole_geUrmdX7;
  SignalTabwrite sTabwrite_5dVdSzOB;
  SignalTabwrite sTabwrite_c2DjzXtG;
  SignalTabwrite sTabwrite_jnLSUggd;
  SignalTabwrite sTabwrite_ol5QyNWW;
  SignalLine sLine_ix9qJEoG;
  ControlVar cVar_ODdHrkvx;
  ControlVar cVar_xefN2xWb;
  ControlPack cPack_2lPZ8NRy;
  ControlBinop cBinop_jaySaagz;
  ControlVar cVar_m3EKAMP3;
  ControlPack cPack_QyyUEuBk;
  ControlVar cVar_aNZ5WOMY;
  ControlVar cVar_mUMjOq9C;
  ControlDelay cDelay_R0AGFgkJ;
  ControlDelay cDelay_KM58s7HG;
  ControlBinop cBinop_osuFk77G;
  HvTable hTable_DYaSlRhE;
  ControlBinop cBinop_Hvwa3q3i;
  ControlVar cVar_PKCpMu1q;
  ControlBinop cBinop_p8hnuevD;
  ControlBinop cBinop_zA9nVotb;
  SignalVarf sVarf_p3JLKD9J;
  SignalVarf sVarf_WVacaQ7w;
  SignalVarf sVarf_EiZDkHzY;
  ControlVar cVar_kfCPvAJ6;
  ControlBinop cBinop_7grBmygo;
  ControlBinop cBinop_y4Gny330;
  SignalVarf sVarf_X8LW4HZy;
  SignalVarf sVarf_2BIj1rbB;
  SignalVarf sVarf_fYGKIVhv;
  ControlBinop cBinop_PjSJ8lha;
  ControlBinop cBinop_QJlua14o;
  ControlBinop cBinop_BSOnoEiy;
  ControlBinop cBinop_Im9XaTdK;
  ControlBinop cBinop_mI9VSfmU;
  ControlBinop cBinop_0oLIqXDl;
  ControlBinop cBinop_1SuOvjzj;
  ControlBinop cBinop_3phDTLVj;
  ControlBinop cBinop_lhrRNYOn;
  SignalVarf sVarf_bJyc68z9;
  ControlVar cVar_jKakNvpE;
  ControlBinop cBinop_vA5cqOH0;
  ControlBinop cBinop_gaAPTlsn;
  ControlBinop cBinop_jNhnnA2H;
  ControlBinop cBinop_gaehlu8B;
  ControlBinop cBinop_cP1D4OO9;
  ControlBinop cBinop_6OWDcR5C;
  ControlBinop cBinop_8c45Pavk;
  SignalVarf sVarf_a2y9uWxd;
  ControlBinop cBinop_Pyj37rxY;
  ControlRandom cRandom_ZdaxPfGj;
  ControlSlice cSlice_NO5cRZLt;
  ControlDelay cDelay_hh1XRNom;
  ControlVar cVar_PIbvHXd6;
  ControlBinop cBinop_P2IIN5Y6;
  ControlBinop cBinop_VuOqOlSQ;
  ControlBinop cBinop_F7IEMl5K;
  ControlTabhead cTabhead_RyvU3PWU;
  ControlVar cVar_mo2tx1bc;
  ControlDelay cDelay_tANuq7nv;
  ControlDelay cDelay_Y14zDpbB;
  ControlBinop cBinop_WW6EYeT6;
  ControlBinop cBinop_2gGgcCnB;
  ControlBinop cBinop_QKiI0lXT;
  ControlBinop cBinop_unSoMnmn;
  ControlBinop cBinop_emwTLRkT;
  ControlBinop cBinop_wVosukry;
  ControlTabhead cTabhead_zSf3h4nV;
  ControlVar cVar_0mzy8eyX;
  ControlDelay cDelay_9Pr7Ek75;
  ControlDelay cDelay_h5VUqwyU;
  ControlBinop cBinop_9t3WLXc7;
  ControlBinop cBinop_z65MOAwy;
  ControlBinop cBinop_ngbybU9Y;
  ControlBinop cBinop_4m26YLAm;
  ControlBinop cBinop_SodMJ3yV;
  ControlBinop cBinop_VQMZqIW9;
  ControlTabhead cTabhead_vf8MpW5m;
  ControlVar cVar_69EXG7nV;
  ControlDelay cDelay_mcJreT0g;
  ControlDelay cDelay_q4EyuiUV;
  ControlBinop cBinop_AIQf7Yog;
  ControlBinop cBinop_25RvDVAh;
  ControlBinop cBinop_XAvvCIcu;
  ControlBinop cBinop_J66uIDKs;
  ControlBinop cBinop_ATbNID9k;
  ControlBinop cBinop_uD7FpctD;
  ControlTabhead cTabhead_5US86sJf;
  ControlVar cVar_8HGBrpHJ;
  ControlDelay cDelay_3rq7jeOh;
  ControlDelay cDelay_Vlmo2uCI;
  ControlBinop cBinop_vti4IXZx;
  ControlBinop cBinop_1433xGbf;
  ControlBinop cBinop_BhevXLae;
  ControlBinop cBinop_QSDg3Br6;
  ControlBinop cBinop_MQMBsB86;
  ControlBinop cBinop_MsCyD43p;
  ControlDelay cDelay_NCPv6bNF;
  ControlDelay cDelay_d1rLeWNE;
  ControlBinop cBinop_Z0DpcWeG;
  HvTable hTable_NyaIKUQ5;
  ControlBinop cBinop_mwECx5Ri;
  ControlDelay cDelay_dx1msDw6;
  ControlDelay cDelay_dspepbfs;
  ControlBinop cBinop_TNErpEws;
  HvTable hTable_TaWDj5vU;
  ControlBinop cBinop_XHaKGXgM;
  ControlDelay cDelay_fpffzd1Q;
  ControlDelay cDelay_WlUfMvGQ;
  ControlBinop cBinop_16OjkEsf;
  HvTable hTable_fiQE0RI9;
  ControlBinop cBinop_nypV30ro;
  ControlDelay cDelay_ZWiuDD3z;
  ControlDelay cDelay_uU8dmnaQ;
  ControlBinop cBinop_fjRPTOkO;
  HvTable hTable_IN7rXJDL;
  ControlBinop cBinop_XCVRBpPh;
  ControlPack cPack_fGt1YB7V;
  ControlPack cPack_p7zoaMGB;
  ControlBinop cBinop_R9kZxlyu;
  ControlBinop cBinop_8VRF0PXU;
  ControlVar cVar_fXgFpsF0;
  ControlBinop cBinop_vsjCPcsV;
  ControlBinop cBinop_Wjsuyo9Z;
  SignalVarf sVarf_J6Ap7flw;
  ControlBinop cBinop_b7pb31ER;
  ControlBinop cBinop_YmlnAKch;
  ControlBinop cBinop_AumYwmke;
  SignalVarf sVarf_BcSoIBbs;
  ControlVar cVar_oHnXd3cT;
  ControlVar cVar_1eWsxQMS;
  ControlVar cVar_YCMr5MlE;
  ControlVar cVar_oFdrLCII;
  ControlIf cIf_7rVdvtEL;
  ControlBinop cBinop_f0BvQ0cr;
  ControlBinop cBinop_ulY4nDMa;
  ControlBinop cBinop_kw6fgnQ1;
  ControlDelay cDelay_RQGpujiK;
  ControlDelay cDelay_lsUvLvH5;
  ControlBinop cBinop_6XCdT3Nk;
  HvTable hTable_bqTOuW1T;
  ControlBinop cBinop_UkvSUk4n;
  ControlTabhead cTabhead_vZBCvVpQ;
  ControlVar cVar_SVESKeA9;
  ControlDelay cDelay_KSGWjcsZ;
  ControlDelay cDelay_qb3xAJ8Y;
  ControlBinop cBinop_awaRR0nD;
  ControlBinop cBinop_eRYlguxa;
  ControlBinop cBinop_7ltIfhPY;
  ControlBinop cBinop_QsKJCxh9;
  ControlBinop cBinop_NydIxXys;
  ControlBinop cBinop_7DiKtxrs;
  ControlDelay cDelay_fbi0B0Rm;
  ControlDelay cDelay_bpEKovGk;
  ControlBinop cBinop_F0FYCCPI;
  HvTable hTable_r3HfJ7py;
  ControlBinop cBinop_H8zhJ6Au;
  ControlTabhead cTabhead_InAl9VQU;
  ControlVar cVar_pKC0yOrJ;
  ControlDelay cDelay_1P2N4euC;
  ControlDelay cDelay_BlrgKH5W;
  ControlBinop cBinop_147p8vxa;
  ControlBinop cBinop_okAmcYku;
  ControlBinop cBinop_ZoSNL2cD;
  ControlBinop cBinop_GsOvjG74;
  ControlBinop cBinop_xHgsX0eh;
  ControlBinop cBinop_7yfIhw8I;
  ControlDelay cDelay_gDTCkO7J;
  ControlDelay cDelay_01d4wnzX;
  ControlBinop cBinop_ApRGEhtz;
  HvTable hTable_WsrASp2G;
  ControlBinop cBinop_RnkMpjD8;
  ControlTabhead cTabhead_8W3uz42X;
  ControlVar cVar_y7ej96da;
  ControlDelay cDelay_pOqwfQJx;
  ControlDelay cDelay_9llx5H16;
  ControlBinop cBinop_TzDSvkz4;
  ControlBinop cBinop_sHEf5Dti;
  ControlBinop cBinop_7N5gIPIH;
  ControlBinop cBinop_tZ30gduz;
  ControlBinop cBinop_WeajDe2r;
  ControlBinop cBinop_is2HBZhF;
  ControlDelay cDelay_cv7vDQxw;
  ControlDelay cDelay_TPHicpsP;
  ControlBinop cBinop_D9V8Elwk;
  HvTable hTable_giTLcA7T;
  ControlBinop cBinop_Cs25OqnJ;
  ControlTabhead cTabhead_ENmo1egN;
  ControlVar cVar_x8ezLMxf;
  ControlDelay cDelay_Ncr2tMQH;
  ControlDelay cDelay_zyJyZv6e;
  ControlBinop cBinop_gmQB5WDs;
  ControlBinop cBinop_WiU9zmIi;
  ControlBinop cBinop_tvDWHSJu;
  ControlBinop cBinop_mRapKcO2;
  ControlBinop cBinop_evhhOGQP;
  ControlBinop cBinop_m2kFOFkK;
  ControlDelay cDelay_tCCXrmvP;
  ControlDelay cDelay_SNfCdIUL;
  ControlBinop cBinop_bSRFVHWX;
  HvTable hTable_q2orfTlk;
  ControlBinop cBinop_axDvTGal;
  ControlTabhead cTabhead_8pBGksOt;
  ControlVar cVar_eHFgmnPJ;
  ControlDelay cDelay_OM2ZTRfz;
  ControlDelay cDelay_rsbZTNnt;
  ControlBinop cBinop_r2pBmShc;
  ControlBinop cBinop_bAGnyWVJ;
  ControlBinop cBinop_tCHPttmq;
  ControlBinop cBinop_RQ8AuKyl;
  ControlBinop cBinop_8iIixZTF;
  ControlBinop cBinop_VahIToIg;
  ControlDelay cDelay_jGZDHNcM;
  ControlDelay cDelay_HpuALlgz;
  ControlBinop cBinop_q5v6X8s0;
  HvTable hTable_qBB091qh;
  ControlBinop cBinop_n2zxn9mG;
  ControlTabhead cTabhead_7iCibBZR;
  ControlVar cVar_NRBGibz3;
  ControlDelay cDelay_HhnCKYkD;
  ControlDelay cDelay_e3Osx1DX;
  ControlBinop cBinop_BYKvi91d;
  ControlBinop cBinop_WzseURxv;
  ControlBinop cBinop_hrmhortT;
  ControlBinop cBinop_WnCx3UwD;
  ControlBinop cBinop_8VqzBlV3;
  ControlBinop cBinop_WRhWegqg;
  ControlVar cVar_DUmfrq7l;
  ControlVar cVar_KakEh7GG;
  ControlPack cPack_Ecxd4Btu;
  ControlVar cVar_I0S6g0Uv;
  ControlBinop cBinop_TPMIZzat;
  ControlBinop cBinop_wpmLQ66b;
  SignalVarf sVarf_WyRUF50p;
  ControlBinop cBinop_7asygAML;
  ControlBinop cBinop_ofa3lR5W;
  ControlBinop cBinop_PWHVUhum;
  SignalVarf sVarf_O9mxsXez;
  ControlVar cVar_WhJY5Ixy;
  ControlBinop cBinop_ynBwZ9kq;
  ControlBinop cBinop_o7cLdUUo;
  SignalVarf sVarf_VfAVIJM5;
  ControlBinop cBinop_n67iGy0F;
  ControlBinop cBinop_SONt1JdT;
  ControlBinop cBinop_Dw6wCyPV;
  SignalVarf sVarf_1GKDkyD0;
  ControlVar cVar_443M7CYE;
  ControlBinop cBinop_tyH9SQr1;
  ControlBinop cBinop_7QEedLZC;
  SignalVarf sVarf_LDkbbEZz;
  ControlBinop cBinop_gLx4zd3K;
  ControlBinop cBinop_0Kfz8Yab;
  ControlBinop cBinop_0XvY5e2o;
  SignalVarf sVarf_Y5IbmkOV;
  ControlBinop cBinop_3WyssFfY;
  ControlBinop cBinop_XgKgFAH9;
  ControlBinop cBinop_s7raUbIz;
  ControlDelay cDelay_PytoHoQl;
  ControlVar cVar_485SeXnK;
  ControlBinop cBinop_4FCgomZ8;
  ControlBinop cBinop_R36tzG9x;
  ControlBinop cBinop_JYhN4ggm;
  ControlVar cVar_YX8v9oc9;
  ControlVar cVar_kry5TWIQ;
  ControlIf cIf_trJmItzA;
  ControlBinop cBinop_xL8F6CSC;
  ControlDelay cDelay_hU4llCfj;
  ControlDelay cDelay_4vJKZcYf;
  ControlBinop cBinop_rXNsuM2R;
  HvTable hTable_L7NJBGh6;
  ControlBinop cBinop_0k3G5vMS;
  ControlTabhead cTabhead_ORVbPI8R;
  ControlVar cVar_7OCxbr6W;
  ControlDelay cDelay_pEeHxv08;
  ControlDelay cDelay_FpqaTGLC;
  ControlBinop cBinop_zh5WTNM6;
  ControlBinop cBinop_GrAJSgMd;
  ControlBinop cBinop_qDzC6Krq;
  ControlBinop cBinop_HjPKrX3s;
  ControlBinop cBinop_o0CfbAvY;
  ControlBinop cBinop_b5P4Ts8H;
  ControlVar cVar_X83T25BI;
  ControlVar cVar_sRuotCL2;
  ControlVar cVar_IdRgGlRI;
  ControlVar cVar_k1paVRUq;
  ControlVar cVar_Q7PM3wci;
  ControlVar cVar_6Iemn6Eg;
  ControlIf cIf_eO2pemkq;
  ControlBinop cBinop_CMDkMiDP;
  ControlVar cVar_Z4iHosQS;
  ControlIf cIf_qGNxcImY;
  ControlBinop cBinop_45f1Jn7a;
  ControlSlice cSlice_MliDOj2o;
  ControlSlice cSlice_mmI4o2q2;
  ControlVar cVar_XvKnZ57B;
  ControlIf cIf_ozGrrXCJ;
  ControlBinop cBinop_yLSXdD7y;
  ControlIf cIf_JpYoQq4j;
  ControlIf cIf_8fUIzGTP;
  ControlIf cIf_Mr1CnmgC;
  ControlIf cIf_IoVsv4au;
  ControlIf cIf_biX90F8G;
  SignalVarf sVarf_WvtFyz98;
  ControlBinop cBinop_ALJgt6ZO;
  ControlBinop cBinop_uewWTS4x;
  ControlBinop cBinop_5jsqlO45;
  ControlBinop cBinop_eqtUJfKh;
  SignalVarf sVarf_tUXS7tFD;
  ControlBinop cBinop_DbC5XjBe;
  ControlBinop cBinop_LRITNHXs;
  SignalVarf sVarf_XnggL2Sl;
  SignalVarf sVarf_hmfLznrA;
  ControlBinop cBinop_VTLhVkPR;
  ControlBinop cBinop_X3uy4Ndk;
  ControlBinop cBinop_DaI1qNjE;
  ControlBinop cBinop_qnsdXAqn;
  ControlBinop cBinop_HJq4D2QH;
  ControlBinop cBinop_QBG7lttO;
  ControlBinop cBinop_u9mfNsck;
  ControlBinop cBinop_rHV1HAsm;
  ControlBinop cBinop_atyEqK7y;
  ControlBinop cBinop_DzqH979z;
  ControlBinop cBinop_fAyPuy9P;
  ControlBinop cBinop_uXtukGZ5;
  ControlBinop cBinop_WeSqvwLv;
};

#endif // _HEAVY_CONTEXT_CHAFFVERB_HPP_
