/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_ChaffVerb.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_ChaffVerb *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_ChaffVerb_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_ChaffVerb));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_ChaffVerb(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_ChaffVerb_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_ChaffVerb));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_ChaffVerb(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_ChaffVerb_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_ChaffVerb();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_ChaffVerb::Heavy_ChaffVerb(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sPhasor_k_init(&sPhasor_afzQn89y, 0.0f, sampleRate);
  numBytes += sLine_init(&sLine_Kkad90Ga);
  numBytes += sLine_init(&sLine_t9TMQyqE);
  numBytes += sTabhead_init(&sTabhead_4pkvc85T, &hTable_DYaSlRhE);
  numBytes += sTabread_init(&sTabread_VeSwpv8V, &hTable_DYaSlRhE, false);
  numBytes += sTabread_init(&sTabread_iQtvS8pZ, &hTable_DYaSlRhE, false);
  numBytes += sTabhead_init(&sTabhead_ekQ8ud6x, &hTable_DYaSlRhE);
  numBytes += sTabread_init(&sTabread_LSTIa4QR, &hTable_DYaSlRhE, false);
  numBytes += sTabread_init(&sTabread_q3rxNhgH, &hTable_DYaSlRhE, false);
  numBytes += sTabwrite_init(&sTabwrite_QRkkhrJc, &hTable_DYaSlRhE);
  numBytes += sRPole_init(&sRPole_8t6iTKa4);
  numBytes += sDel1_init(&sDel1_jut503ns);
  numBytes += sTabread_init(&sTabread_B4m31igs, &hTable_L7NJBGh6, true);
  numBytes += sTabwrite_init(&sTabwrite_azEBcTCe, &hTable_L7NJBGh6);
  numBytes += sTabread_init(&sTabread_7WDI4aPT, &hTable_NyaIKUQ5, true);
  numBytes += sRPole_init(&sRPole_fNTUQ2jn);
  numBytes += sLine_init(&sLine_xbzsq2FY);
  numBytes += sLine_init(&sLine_B8tHs58F);
  numBytes += sTabread_init(&sTabread_5vBrt5Lt, &hTable_bqTOuW1T, true);
  numBytes += sTabread_init(&sTabread_1Kl3wrmP, &hTable_r3HfJ7py, true);
  numBytes += sTabread_init(&sTabread_cLcPVf2T, &hTable_WsrASp2G, true);
  numBytes += sTabread_init(&sTabread_RbvJeJAQ, &hTable_giTLcA7T, true);
  numBytes += sTabread_init(&sTabread_8xYydRsB, &hTable_qBB091qh, true);
  numBytes += sTabread_init(&sTabread_18WxEltQ, &hTable_q2orfTlk, true);
  numBytes += sTabwrite_init(&sTabwrite_bQeLtBe0, &hTable_bqTOuW1T);
  numBytes += sTabwrite_init(&sTabwrite_G4XvBQ0b, &hTable_r3HfJ7py);
  numBytes += sTabwrite_init(&sTabwrite_WHZaySni, &hTable_WsrASp2G);
  numBytes += sTabwrite_init(&sTabwrite_S9UN3mKO, &hTable_giTLcA7T);
  numBytes += sTabwrite_init(&sTabwrite_4QFm9txG, &hTable_q2orfTlk);
  numBytes += sTabwrite_init(&sTabwrite_ePBn4bHE, &hTable_qBB091qh);
  numBytes += sTabread_init(&sTabread_gnHu58Jr, &hTable_TaWDj5vU, true);
  numBytes += sRPole_init(&sRPole_i9JFecmT);
  numBytes += sTabread_init(&sTabread_ahU3pB3H, &hTable_fiQE0RI9, true);
  numBytes += sRPole_init(&sRPole_73OZHrfu);
  numBytes += sTabread_init(&sTabread_yqQ1pdWX, &hTable_IN7rXJDL, true);
  numBytes += sRPole_init(&sRPole_geUrmdX7);
  numBytes += sTabwrite_init(&sTabwrite_5dVdSzOB, &hTable_NyaIKUQ5);
  numBytes += sTabwrite_init(&sTabwrite_c2DjzXtG, &hTable_TaWDj5vU);
  numBytes += sTabwrite_init(&sTabwrite_jnLSUggd, &hTable_fiQE0RI9);
  numBytes += sTabwrite_init(&sTabwrite_ol5QyNWW, &hTable_IN7rXJDL);
  numBytes += sLine_init(&sLine_ix9qJEoG);
  numBytes += cVar_init_f(&cVar_ODdHrkvx, 0.0f);
  numBytes += cVar_init_f(&cVar_xefN2xWb, 0.0f);
  numBytes += cPack_init(&cPack_2lPZ8NRy, 2, 0.0f, 200.0f);
  numBytes += cVar_init_f(&cVar_m3EKAMP3, 0.0f);
  numBytes += cPack_init(&cPack_QyyUEuBk, 2, 0.0f, 200.0f);
  numBytes += cVar_init_f(&cVar_aNZ5WOMY, 0.0f);
  numBytes += cVar_init_f(&cVar_mUMjOq9C, 0.0f);
  numBytes += cDelay_init(this, &cDelay_R0AGFgkJ, 0.0f);
  numBytes += cDelay_init(this, &cDelay_KM58s7HG, 0.0f);
  numBytes += hTable_init(&hTable_DYaSlRhE, 256);
  numBytes += cVar_init_s(&cVar_PKCpMu1q, "del-1002-shifter");
  numBytes += sVarf_init(&sVarf_p3JLKD9J, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_WVacaQ7w, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_EiZDkHzY, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_kfCPvAJ6, "del-1002-shifter");
  numBytes += sVarf_init(&sVarf_X8LW4HZy, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_2BIj1rbB, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_fYGKIVhv, 0.0f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_PjSJ8lha, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_bJyc68z9, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_jKakNvpE, 0.0f);
  numBytes += cBinop_init(&cBinop_8c45Pavk, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_a2y9uWxd, 0.0f, 0.0f, false);
  numBytes += cRandom_init(&cRandom_ZdaxPfGj, -1374676165);
  numBytes += cSlice_init(&cSlice_NO5cRZLt, 1, 1);
  numBytes += cDelay_init(this, &cDelay_hh1XRNom, 0.0f);
  numBytes += cVar_init_f(&cVar_PIbvHXd6, 5.0f);
  numBytes += cBinop_init(&cBinop_F7IEMl5K, 0.0f); // __mul
  numBytes += cTabhead_init(&cTabhead_RyvU3PWU, &hTable_NyaIKUQ5);
  numBytes += cVar_init_s(&cVar_mo2tx1bc, "del-1052-del1");
  numBytes += cDelay_init(this, &cDelay_tANuq7nv, 58.6435f);
  numBytes += cDelay_init(this, &cDelay_Y14zDpbB, 0.0f);
  numBytes += cBinop_init(&cBinop_WW6EYeT6, 58.6435f); // __mul
  numBytes += cBinop_init(&cBinop_QKiI0lXT, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_unSoMnmn, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_wVosukry, 0.0f); // __sub
  numBytes += cTabhead_init(&cTabhead_zSf3h4nV, &hTable_TaWDj5vU);
  numBytes += cVar_init_s(&cVar_0mzy8eyX, "del-1052-del2");
  numBytes += cDelay_init(this, &cDelay_9Pr7Ek75, 69.4325f);
  numBytes += cDelay_init(this, &cDelay_h5VUqwyU, 0.0f);
  numBytes += cBinop_init(&cBinop_9t3WLXc7, 69.4325f); // __mul
  numBytes += cBinop_init(&cBinop_ngbybU9Y, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_4m26YLAm, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_VQMZqIW9, 0.0f); // __sub
  numBytes += cTabhead_init(&cTabhead_vf8MpW5m, &hTable_fiQE0RI9);
  numBytes += cVar_init_s(&cVar_69EXG7nV, "del-1052-del3");
  numBytes += cDelay_init(this, &cDelay_mcJreT0g, 74.5234f);
  numBytes += cDelay_init(this, &cDelay_q4EyuiUV, 0.0f);
  numBytes += cBinop_init(&cBinop_AIQf7Yog, 74.5234f); // __mul
  numBytes += cBinop_init(&cBinop_XAvvCIcu, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_J66uIDKs, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_uD7FpctD, 0.0f); // __sub
  numBytes += cTabhead_init(&cTabhead_5US86sJf, &hTable_IN7rXJDL);
  numBytes += cVar_init_s(&cVar_8HGBrpHJ, "del-1052-del4");
  numBytes += cDelay_init(this, &cDelay_3rq7jeOh, 86.1244f);
  numBytes += cDelay_init(this, &cDelay_Vlmo2uCI, 0.0f);
  numBytes += cBinop_init(&cBinop_vti4IXZx, 86.1244f); // __mul
  numBytes += cBinop_init(&cBinop_BhevXLae, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_QSDg3Br6, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_MsCyD43p, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_NCPv6bNF, 0.0f);
  numBytes += cDelay_init(this, &cDelay_d1rLeWNE, 0.0f);
  numBytes += hTable_init(&hTable_NyaIKUQ5, 256);
  numBytes += cDelay_init(this, &cDelay_dx1msDw6, 0.0f);
  numBytes += cDelay_init(this, &cDelay_dspepbfs, 0.0f);
  numBytes += hTable_init(&hTable_TaWDj5vU, 256);
  numBytes += cDelay_init(this, &cDelay_fpffzd1Q, 0.0f);
  numBytes += cDelay_init(this, &cDelay_WlUfMvGQ, 0.0f);
  numBytes += hTable_init(&hTable_fiQE0RI9, 256);
  numBytes += cDelay_init(this, &cDelay_ZWiuDD3z, 0.0f);
  numBytes += cDelay_init(this, &cDelay_uU8dmnaQ, 0.0f);
  numBytes += hTable_init(&hTable_IN7rXJDL, 256);
  numBytes += cPack_init(&cPack_fGt1YB7V, 2, 0.0f, 30.0f);
  numBytes += cPack_init(&cPack_p7zoaMGB, 2, 0.0f, 50.0f);
  numBytes += cVar_init_f(&cVar_fXgFpsF0, 22050.0f);
  numBytes += cBinop_init(&cBinop_vsjCPcsV, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_J6Ap7flw, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_BcSoIBbs, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_oHnXd3cT, 0.0f);
  numBytes += cVar_init_f(&cVar_1eWsxQMS, 0.0f);
  numBytes += cVar_init_f(&cVar_YCMr5MlE, 0.0f);
  numBytes += cVar_init_f(&cVar_oFdrLCII, 0.0f);
  numBytes += cIf_init(&cIf_7rVdvtEL, false);
  numBytes += cDelay_init(this, &cDelay_RQGpujiK, 0.0f);
  numBytes += cDelay_init(this, &cDelay_lsUvLvH5, 0.0f);
  numBytes += hTable_init(&hTable_bqTOuW1T, 256);
  numBytes += cTabhead_init(&cTabhead_vZBCvVpQ, &hTable_bqTOuW1T);
  numBytes += cVar_init_s(&cVar_SVESKeA9, "del-1052-ref1");
  numBytes += cDelay_init(this, &cDelay_KSGWjcsZ, 43.5337f);
  numBytes += cDelay_init(this, &cDelay_qb3xAJ8Y, 0.0f);
  numBytes += cBinop_init(&cBinop_awaRR0nD, 43.5337f); // __mul
  numBytes += cBinop_init(&cBinop_7ltIfhPY, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_QsKJCxh9, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_7DiKtxrs, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_fbi0B0Rm, 0.0f);
  numBytes += cDelay_init(this, &cDelay_bpEKovGk, 0.0f);
  numBytes += hTable_init(&hTable_r3HfJ7py, 256);
  numBytes += cTabhead_init(&cTabhead_InAl9VQU, &hTable_r3HfJ7py);
  numBytes += cVar_init_s(&cVar_pKC0yOrJ, "del-1052-ref2");
  numBytes += cDelay_init(this, &cDelay_1P2N4euC, 25.796f);
  numBytes += cDelay_init(this, &cDelay_BlrgKH5W, 0.0f);
  numBytes += cBinop_init(&cBinop_147p8vxa, 25.796f); // __mul
  numBytes += cBinop_init(&cBinop_ZoSNL2cD, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_GsOvjG74, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_7yfIhw8I, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_gDTCkO7J, 0.0f);
  numBytes += cDelay_init(this, &cDelay_01d4wnzX, 0.0f);
  numBytes += hTable_init(&hTable_WsrASp2G, 256);
  numBytes += cTabhead_init(&cTabhead_8W3uz42X, &hTable_WsrASp2G);
  numBytes += cVar_init_s(&cVar_y7ej96da, "del-1052-ref3");
  numBytes += cDelay_init(this, &cDelay_pOqwfQJx, 19.392f);
  numBytes += cDelay_init(this, &cDelay_9llx5H16, 0.0f);
  numBytes += cBinop_init(&cBinop_TzDSvkz4, 19.392f); // __mul
  numBytes += cBinop_init(&cBinop_7N5gIPIH, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_tZ30gduz, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_is2HBZhF, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_cv7vDQxw, 0.0f);
  numBytes += cDelay_init(this, &cDelay_TPHicpsP, 0.0f);
  numBytes += hTable_init(&hTable_giTLcA7T, 256);
  numBytes += cTabhead_init(&cTabhead_ENmo1egN, &hTable_giTLcA7T);
  numBytes += cVar_init_s(&cVar_x8ezLMxf, "del-1052-ref4");
  numBytes += cDelay_init(this, &cDelay_Ncr2tMQH, 16.364f);
  numBytes += cDelay_init(this, &cDelay_zyJyZv6e, 0.0f);
  numBytes += cBinop_init(&cBinop_gmQB5WDs, 16.364f); // __mul
  numBytes += cBinop_init(&cBinop_tvDWHSJu, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_mRapKcO2, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_m2kFOFkK, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_tCCXrmvP, 0.0f);
  numBytes += cDelay_init(this, &cDelay_SNfCdIUL, 0.0f);
  numBytes += hTable_init(&hTable_q2orfTlk, 256);
  numBytes += cTabhead_init(&cTabhead_8pBGksOt, &hTable_q2orfTlk);
  numBytes += cVar_init_s(&cVar_eHFgmnPJ, "del-1052-ref6");
  numBytes += cDelay_init(this, &cDelay_OM2ZTRfz, 4.2546f);
  numBytes += cDelay_init(this, &cDelay_rsbZTNnt, 0.0f);
  numBytes += cBinop_init(&cBinop_r2pBmShc, 4.2546f); // __mul
  numBytes += cBinop_init(&cBinop_tCHPttmq, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_RQ8AuKyl, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_VahIToIg, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_jGZDHNcM, 0.0f);
  numBytes += cDelay_init(this, &cDelay_HpuALlgz, 0.0f);
  numBytes += hTable_init(&hTable_qBB091qh, 256);
  numBytes += cTabhead_init(&cTabhead_7iCibBZR, &hTable_qBB091qh);
  numBytes += cVar_init_s(&cVar_NRBGibz3, "del-1052-ref5");
  numBytes += cDelay_init(this, &cDelay_HhnCKYkD, 7.645f);
  numBytes += cDelay_init(this, &cDelay_e3Osx1DX, 0.0f);
  numBytes += cBinop_init(&cBinop_BYKvi91d, 7.645f); // __mul
  numBytes += cBinop_init(&cBinop_hrmhortT, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_WnCx3UwD, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_WRhWegqg, 0.0f); // __sub
  numBytes += cVar_init_f(&cVar_DUmfrq7l, 0.0f);
  numBytes += cVar_init_f(&cVar_KakEh7GG, 0.0f);
  numBytes += cPack_init(&cPack_Ecxd4Btu, 2, 0.0f, 50.0f);
  numBytes += cVar_init_f(&cVar_I0S6g0Uv, 22050.0f);
  numBytes += cBinop_init(&cBinop_TPMIZzat, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_WyRUF50p, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_O9mxsXez, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_WhJY5Ixy, 22050.0f);
  numBytes += cBinop_init(&cBinop_ynBwZ9kq, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_VfAVIJM5, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_1GKDkyD0, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_443M7CYE, 22050.0f);
  numBytes += cBinop_init(&cBinop_tyH9SQr1, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_LDkbbEZz, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Y5IbmkOV, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_PytoHoQl, 0.0f);
  numBytes += cVar_init_f(&cVar_485SeXnK, 1000.0f);
  numBytes += cBinop_init(&cBinop_JYhN4ggm, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_YX8v9oc9, 0.0f);
  numBytes += cVar_init_f(&cVar_kry5TWIQ, 0.0f);
  numBytes += cIf_init(&cIf_trJmItzA, false);
  numBytes += cDelay_init(this, &cDelay_hU4llCfj, 0.0f);
  numBytes += cDelay_init(this, &cDelay_4vJKZcYf, 0.0f);
  numBytes += hTable_init(&hTable_L7NJBGh6, 256);
  numBytes += cTabhead_init(&cTabhead_ORVbPI8R, &hTable_L7NJBGh6);
  numBytes += cVar_init_s(&cVar_7OCxbr6W, "del-1001-del1");
  numBytes += cDelay_init(this, &cDelay_pEeHxv08, 150.0f);
  numBytes += cDelay_init(this, &cDelay_FpqaTGLC, 0.0f);
  numBytes += cBinop_init(&cBinop_zh5WTNM6, 150.0f); // __mul
  numBytes += cBinop_init(&cBinop_qDzC6Krq, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_HjPKrX3s, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_b5P4Ts8H, 0.0f); // __sub
  numBytes += cVar_init_f(&cVar_X83T25BI, 0.0f);
  numBytes += cVar_init_f(&cVar_sRuotCL2, 0.0f);
  numBytes += cVar_init_f(&cVar_IdRgGlRI, 0.0f);
  numBytes += cVar_init_f(&cVar_k1paVRUq, 0.0f);
  numBytes += cVar_init_f(&cVar_Q7PM3wci, 0.0f);
  numBytes += cVar_init_f(&cVar_6Iemn6Eg, 0.0f);
  numBytes += cIf_init(&cIf_eO2pemkq, false);
  numBytes += cVar_init_f(&cVar_Z4iHosQS, 0.0f);
  numBytes += cIf_init(&cIf_qGNxcImY, false);
  numBytes += cSlice_init(&cSlice_MliDOj2o, 1, -1);
  numBytes += cSlice_init(&cSlice_mmI4o2q2, 1, -1);
  numBytes += cVar_init_f(&cVar_XvKnZ57B, 0.0f);
  numBytes += cIf_init(&cIf_ozGrrXCJ, false);
  numBytes += cBinop_init(&cBinop_yLSXdD7y, 0.0f); // __neq
  numBytes += cIf_init(&cIf_JpYoQq4j, false);
  numBytes += cIf_init(&cIf_8fUIzGTP, false);
  numBytes += cIf_init(&cIf_Mr1CnmgC, false);
  numBytes += cIf_init(&cIf_IoVsv4au, true);
  numBytes += cIf_init(&cIf_biX90F8G, false);
  numBytes += sVarf_init(&sVarf_WvtFyz98, 1.0f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_5jsqlO45, 4.0f); // __unimod
  numBytes += sVarf_init(&sVarf_tUXS7tFD, 0.1f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_DbC5XjBe, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_LRITNHXs, 0.0f); // __add
  numBytes += sVarf_init(&sVarf_XnggL2Sl, 0.65f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_hmfLznrA, 0.55f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_X3uy4Ndk, 1.0f); // __mul
  numBytes += cBinop_init(&cBinop_atyEqK7y, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_DzqH979z, 1.0f); // __mul
  numBytes += cBinop_init(&cBinop_fAyPuy9P, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_uXtukGZ5, 1.0f); // __mul
  numBytes += cBinop_init(&cBinop_WeSqvwLv, 0.0f); // __add
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_ChaffVerb::~Heavy_ChaffVerb() {
  cPack_free(&cPack_2lPZ8NRy);
  cPack_free(&cPack_QyyUEuBk);
  hTable_free(&hTable_DYaSlRhE);
  hTable_free(&hTable_NyaIKUQ5);
  hTable_free(&hTable_TaWDj5vU);
  hTable_free(&hTable_fiQE0RI9);
  hTable_free(&hTable_IN7rXJDL);
  cPack_free(&cPack_fGt1YB7V);
  cPack_free(&cPack_p7zoaMGB);
  hTable_free(&hTable_bqTOuW1T);
  hTable_free(&hTable_r3HfJ7py);
  hTable_free(&hTable_WsrASp2G);
  hTable_free(&hTable_giTLcA7T);
  hTable_free(&hTable_q2orfTlk);
  hTable_free(&hTable_qBB091qh);
  cPack_free(&cPack_Ecxd4Btu);
  hTable_free(&hTable_L7NJBGh6);
}

HvTable *Heavy_ChaffVerb::getTableForHash(hv_uint32_t tableHash) {switch (tableHash) {
    case 0xA1445E2C: return &hTable_DYaSlRhE; // del-1002-shifter
    case 0xAAA0EB60: return &hTable_NyaIKUQ5; // del-1052-del1
    case 0xA2AC524D: return &hTable_TaWDj5vU; // del-1052-del2
    case 0xE36A35B: return &hTable_fiQE0RI9; // del-1052-del3
    case 0x48CE0509: return &hTable_IN7rXJDL; // del-1052-del4
    case 0xE34D6E72: return &hTable_bqTOuW1T; // del-1052-ref1
    case 0x6A1027AB: return &hTable_r3HfJ7py; // del-1052-ref2
    case 0xA37C6D49: return &hTable_WsrASp2G; // del-1052-ref3
    case 0xCEFE5FE5: return &hTable_giTLcA7T; // del-1052-ref4
    case 0x48EB8BBB: return &hTable_q2orfTlk; // del-1052-ref6
    case 0xCC6F73D5: return &hTable_qBB091qh; // del-1052-ref5
    case 0xED65564F: return &hTable_L7NJBGh6; // del-1001-del1
    default: return nullptr;
  }
}

void Heavy_ChaffVerb::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0x1F30993F: { // A__LFO_Period
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_x4w58j7N_sendMessage);
      break;
    }
    case 0x1A2B8E9F: { // A__LFO_Steps_Scale__Type2
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_EhJQp0f0_sendMessage);
      break;
    }
    case 0xBE3344C8: { // A__LFO_Steps__Type2
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_66BxQk6g_sendMessage);
      break;
    }
    case 0x7369936E: { // A__LFO_Switch
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_R27U671w_sendMessage);
      break;
    }
    case 0xD64CFD23: { // A__LFO_type
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Yq18nDfq_sendMessage);
      break;
    }
    case 0x51447E19: { // B__General_Offset
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_WVF18ach_sendMessage);
      break;
    }
    case 0xA10FCFC4: { // B__General_Scale
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_xXFBhsqU_sendMessage);
      break;
    }
    case 0x7EFB8E46: { // C__Random_LFO_Offset
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_tYZtLglG_sendMessage);
      break;
    }
    case 0xE6223016: { // C__Random_LFO_Period
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_mMpD8sR2_sendMessage);
      break;
    }
    case 0x3281900D: { // C__Random_LFO_Scale
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_86arlxyv_sendMessage);
      break;
    }
    case 0x6150BC53: { // C__Random_LFO_Switch
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Jn3t7dGT_sendMessage);
      break;
    }
    case 0x9CBB1BF3: { // D__Shift_Microtone
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_qOout72y_sendMessage);
      break;
    }
    case 0x4439D71: { // D__Shift_Transpose
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_WQaP177n_sendMessage);
      break;
    }
    case 0x890283C2: { // E__Fx_Level
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_kZFs9edU_sendMessage);
      break;
    }
    case 0x12962685: { // E__HiPass_Freq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_qUoUOHPz_sendMessage);
      break;
    }
    case 0x183CFEE5: { // E__Shift_Delay
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_l5kzDwJD_sendMessage);
      break;
    }
    case 0x57FF40DB: { // E__Shift_Window
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_gEFiBOlR_sendMessage);
      break;
    }
    case 0x69A91334: { // F__FX_Delay
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_O94JcZ2g_sendMessage);
      break;
    }
    case 0x68D029F7: { // F__FX_Delay_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_m65WsHUJ_sendMessage);
      break;
    }
    case 0xD63693D0: { // Mix__Dry_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Qht5EUN4_sendMessage);
      break;
    }
    case 0x1FC3C02C: { // Mix__Dry_Vol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_GfgBm8zT_sendMessage);
      break;
    }
    case 0x58653D84: { // Mix__Reverb_Level
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_2U88Decy_sendMessage);
      break;
    }
    case 0xE764F673: { // Mix__Reverb_Vol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_XIR4osph_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_GMfRmNf2_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_ChaffVerb::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "A__LFO_Period";
        info->hash = 0x1F30993F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 4000.0f;
        info->defaultVal = 1500.0f;
        break;
      }
      case 1: {
        info->name = "A__LFO_Steps_Scale__Type2";
        info->hash = 0x1A2B8E9F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -5.0f;
        info->maxVal = 5.0f;
        info->defaultVal = 1.0f;
        break;
      }
      case 2: {
        info->name = "A__LFO_Steps__Type2";
        info->hash = 0xBE3344C8;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 2.0f;
        info->maxVal = 10.0f;
        info->defaultVal = 4.0f;
        break;
      }
      case 3: {
        info->name = "A__LFO_Switch";
        info->hash = 0x7369936E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 4: {
        info->name = "A__LFO_type";
        info->hash = 0xD64CFD23;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 2.99f;
        info->defaultVal = 0.0f;
        break;
      }
      case 5: {
        info->name = "B__General_Offset";
        info->hash = 0x51447E19;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -2.0f;
        info->maxVal = 2.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 6: {
        info->name = "B__General_Scale";
        info->hash = 0xA10FCFC4;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -7.0f;
        info->maxVal = 7.0f;
        info->defaultVal = 1.0f;
        break;
      }
      case 7: {
        info->name = "C__Random_LFO_Offset";
        info->hash = 0x7EFB8E46;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -2.0f;
        info->maxVal = 2.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 8: {
        info->name = "C__Random_LFO_Period";
        info->hash = 0xE6223016;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 4000.0f;
        info->defaultVal = 1500.0f;
        break;
      }
      case 9: {
        info->name = "C__Random_LFO_Scale";
        info->hash = 0x3281900D;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -7.0f;
        info->maxVal = 7.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 10: {
        info->name = "C__Random_LFO_Switch";
        info->hash = 0x6150BC53;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 11: {
        info->name = "D__Shift_Microtone";
        info->hash = 0x9CBB1BF3;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -1.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 12: {
        info->name = "D__Shift_Transpose";
        info->hash = 0x4439D71;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -36.0f;
        info->maxVal = 36.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 13: {
        info->name = "E__Fx_Level";
        info->hash = 0x890283C2;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.7f;
        break;
      }
      case 14: {
        info->name = "E__HiPass_Freq";
        info->hash = 0x12962685;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 100.0f;
        info->maxVal = 2500.0f;
        info->defaultVal = 800.0f;
        break;
      }
      case 15: {
        info->name = "E__Shift_Delay";
        info->hash = 0x183CFEE5;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 500.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 16: {
        info->name = "E__Shift_Window";
        info->hash = 0x57FF40DB;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 3500.0f;
        info->defaultVal = 1000.0f;
        break;
      }
      case 17: {
        info->name = "F__FX_Delay";
        info->hash = 0x69A91334;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 2000.0f;
        info->defaultVal = 500.0f;
        break;
      }
      case 18: {
        info->name = "F__FX_Delay_Feedback";
        info->hash = 0x68D029F7;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.97f;
        info->defaultVal = 0.65f;
        break;
      }
      case 19: {
        info->name = "Mix__Dry_Mix";
        info->hash = 0xD63693D0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.45f;
        break;
      }
      case 20: {
        info->name = "Mix__Dry_Vol";
        info->hash = 0x1FC3C02C;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.1f;
        break;
      }
      case 21: {
        info->name = "Mix__Reverb_Level";
        info->hash = 0x58653D84;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.85f;
        break;
      }
      case 22: {
        info->name = "Mix__Reverb_Vol";
        info->hash = 0xE764F673;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.5f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 23;
}



/*
 * Send Function Implementations
 */


void Heavy_ChaffVerb::cVar_ODdHrkvx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.05776f, 0, m, &cBinop_Im9XaTdK_sendMessage);
}

void Heavy_ChaffVerb::cVar_xefN2xWb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_1SuOvjzj_sendMessage);
}

void Heavy_ChaffVerb::cPack_2lPZ8NRy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sLine_onMessage(_c, &Context(_c)->sLine_Kkad90Ga, 0, m, NULL);
}

void Heavy_ChaffVerb::cUnop_ozplKQkS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_m3EKAMP3, 0, m, &cVar_m3EKAMP3_sendMessage);
}

void Heavy_ChaffVerb::cBinop_jaySaagz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_EXP, m, &cUnop_ozplKQkS_sendMessage);
}

void Heavy_ChaffVerb::cVar_m3EKAMP3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_BSOnoEiy_sendMessage);
}

void Heavy_ChaffVerb::cPack_QyyUEuBk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sLine_onMessage(_c, &Context(_c)->sLine_t9TMQyqE, 0, m, NULL);
}

void Heavy_ChaffVerb::cVar_aNZ5WOMY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.5f, 0, m, &cBinop_0oLIqXDl_sendMessage);
}

void Heavy_ChaffVerb::cVar_mUMjOq9C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sPhasor_k_onMessage(_c, &Context(_c)->sPhasor_afzQn89y, 0, m);
}

void Heavy_ChaffVerb::cMsg_kMeJbgVr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_CIwYMqHx_sendMessage);
}

void Heavy_ChaffVerb::cSystem_CIwYMqHx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_Hvwa3q3i_sendMessage);
}

void Heavy_ChaffVerb::cDelay_R0AGFgkJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_R0AGFgkJ, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_KM58s7HG, 0, m, &cDelay_KM58s7HG_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_R0AGFgkJ, 0, m, &cDelay_R0AGFgkJ_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_QRkkhrJc, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_KM58s7HG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_KM58s7HG, m);
  cMsg_QIH6Pwp6_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_fKYpes2Y_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_uMKFuozN_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_osuFk77G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_X0uDP7Jy_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_DYaSlRhE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Uf2era6k_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_R0AGFgkJ, 2, m, &cDelay_R0AGFgkJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VA1HK4mZ_sendMessage);
}

void Heavy_ChaffVerb::cMsg_X0uDP7Jy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_DYaSlRhE, 0, m, &hTable_DYaSlRhE_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Hvwa3q3i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_osuFk77G_sendMessage);
}

void Heavy_ChaffVerb::cMsg_QIH6Pwp6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_DYaSlRhE, 0, m, &hTable_DYaSlRhE_sendMessage);
}

void Heavy_ChaffVerb::cCast_VA1HK4mZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_R0AGFgkJ, 0, m, &cDelay_R0AGFgkJ_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Uf2era6k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_KM58s7HG, 2, m, &cDelay_KM58s7HG_sendMessage);
}

void Heavy_ChaffVerb::cMsg_uMKFuozN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_QRkkhrJc, 1, m, NULL);
}

void Heavy_ChaffVerb::cMsg_nBDibG1z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_kLKXpP0G_sendMessage);
}

void Heavy_ChaffVerb::cSystem_kLKXpP0G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_p8hnuevD_sendMessage);
}

void Heavy_ChaffVerb::cVar_PKCpMu1q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_o6LfQrCv_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSystem_pHxEUnZn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_zA9nVotb_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_p3JLKD9J, m);
}

void Heavy_ChaffVerb::cBinop_p8hnuevD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_WVacaQ7w, m);
}

void Heavy_ChaffVerb::cMsg_o6LfQrCv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_pHxEUnZn_sendMessage);
}

void Heavy_ChaffVerb::cBinop_zA9nVotb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_EiZDkHzY, m);
}

void Heavy_ChaffVerb::cMsg_7ZHOAvsJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_87qPGwik_sendMessage);
}

void Heavy_ChaffVerb::cSystem_87qPGwik_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_7grBmygo_sendMessage);
}

void Heavy_ChaffVerb::cVar_kfCPvAJ6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JYSvy8FX_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSystem_FdWea3xN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_y4Gny330_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_X8LW4HZy, m);
}

void Heavy_ChaffVerb::cBinop_7grBmygo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_2BIj1rbB, m);
}

void Heavy_ChaffVerb::cMsg_JYSvy8FX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_FdWea3xN_sendMessage);
}

void Heavy_ChaffVerb::cBinop_y4Gny330_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_fYGKIVhv, m);
}

void Heavy_ChaffVerb::cBinop_PjSJ8lha_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_mUMjOq9C, 0, m, &cVar_mUMjOq9C_sendMessage);
}

void Heavy_ChaffVerb::cBinop_QJlua14o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mLzGq9vd_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XPJbWSir_sendMessage);
}

void Heavy_ChaffVerb::cCast_XPJbWSir_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PjSJ8lha, HV_BINOP_DIVIDE, 0, m, &cBinop_PjSJ8lha_sendMessage);
}

void Heavy_ChaffVerb::cCast_mLzGq9vd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PjSJ8lha, HV_BINOP_DIVIDE, 1, m, &cBinop_PjSJ8lha_sendMessage);
}

void Heavy_ChaffVerb::cBinop_BSOnoEiy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_mI9VSfmU_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Im9XaTdK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 87.3365f, 0, m, &cBinop_jaySaagz_sendMessage);
}

void Heavy_ChaffVerb::cBinop_mI9VSfmU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PjSJ8lha, HV_BINOP_DIVIDE, 0, m, &cBinop_PjSJ8lha_sendMessage);
}

void Heavy_ChaffVerb::cBinop_0oLIqXDl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_QyyUEuBk, 0, m, &cPack_QyyUEuBk_sendMessage);
}

void Heavy_ChaffVerb::cBinop_1SuOvjzj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.001f, 0, m, &cBinop_QJlua14o_sendMessage);
  cPack_onMessage(_c, &Context(_c)->cPack_2lPZ8NRy, 0, m, &cPack_2lPZ8NRy_sendMessage);
}

void Heavy_ChaffVerb::cUnop_HWqVJgI6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_8fUIzGTP, 0, m, &cIf_8fUIzGTP_sendMessage);
}

void Heavy_ChaffVerb::cSwitchcase_zZCwqSRV_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Qzq5r47a_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wSM6SgXA_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0YolKjII_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cCast_Qzq5r47a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WuzidbFT_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cCast_wSM6SgXA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uhGsp3iS_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cCast_0YolKjII_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_X8DgBo2I_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_3phDTLVj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_lhrRNYOn_sendMessage);
}

void Heavy_ChaffVerb::cBinop_lhrRNYOn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_vA5cqOH0_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_gaehlu8B_sendMessage);
}

void Heavy_ChaffVerb::cVar_jKakNvpE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_cP1D4OO9_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Aejd6rNt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_0NbQNj1g_sendMessage);
}

void Heavy_ChaffVerb::cSystem_0NbQNj1g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8c45Pavk, HV_BINOP_DIVIDE, 1, m, &cBinop_8c45Pavk_sendMessage);
}

void Heavy_ChaffVerb::cBinop_vA5cqOH0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_gaAPTlsn_sendMessage);
}

void Heavy_ChaffVerb::cBinop_gaAPTlsn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_a2y9uWxd, m);
}

void Heavy_ChaffVerb::cMsg_WMMswPXT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_jNhnnA2H_sendMessage);
}

void Heavy_ChaffVerb::cBinop_jNhnnA2H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_3phDTLVj_sendMessage);
}

void Heavy_ChaffVerb::cBinop_gaehlu8B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_bJyc68z9, m);
}

void Heavy_ChaffVerb::cBinop_cP1D4OO9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_6OWDcR5C_sendMessage);
}

void Heavy_ChaffVerb::cBinop_6OWDcR5C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8c45Pavk, HV_BINOP_DIVIDE, 0, m, &cBinop_8c45Pavk_sendMessage);
}

void Heavy_ChaffVerb::cBinop_8c45Pavk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WMMswPXT_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_3Uv6Fd8p_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7E64BD01: { // "seed"
      cSlice_onMessage(_c, &Context(_c)->cSlice_NO5cRZLt, 0, m, &cSlice_NO5cRZLt_sendMessage);
      break;
    }
    default: {
      cRandom_onMessage(_c, &Context(_c)->cRandom_ZdaxPfGj, 0, m, &cRandom_ZdaxPfGj_sendMessage);
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_Pyj37rxY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_FLOOR, m, &cUnop_Nym7pZnr_sendMessage);
}

void Heavy_ChaffVerb::cUnop_Nym7pZnr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 50.0f, 0, m, &cBinop_uewWTS4x_sendMessage);
}

void Heavy_ChaffVerb::cRandom_ZdaxPfGj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 100.0f, 0, m, &cBinop_Pyj37rxY_sendMessage);
}

void Heavy_ChaffVerb::cSlice_NO5cRZLt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cRandom_onMessage(_c, &Context(_c)->cRandom_ZdaxPfGj, 1, m, &cRandom_ZdaxPfGj_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cSwitchcase_Tcoz9cTr_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cMsg_vSXwdg7D_sendMessage(_c, 0, m);
      break;
    }
    case 0x7A5B032D: { // "stop"
      cMsg_vSXwdg7D_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TLdtHPIk_sendMessage);
      break;
    }
  }
}

void Heavy_ChaffVerb::cDelay_hh1XRNom_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_hh1XRNom, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_hh1XRNom, 0, m, &cDelay_hh1XRNom_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_YX8v9oc9, 0, m, &cVar_YX8v9oc9_sendMessage);
}

void Heavy_ChaffVerb::cCast_TLdtHPIk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vSXwdg7D_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_hh1XRNom, 0, m, &cDelay_hh1XRNom_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_YX8v9oc9, 0, m, &cVar_YX8v9oc9_sendMessage);
}

void Heavy_ChaffVerb::cMsg_5VbXoVqO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_b4L0Nkf8_sendMessage);
}

void Heavy_ChaffVerb::cSystem_b4L0Nkf8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_VuOqOlSQ_sendMessage);
}

void Heavy_ChaffVerb::cVar_PIbvHXd6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_F7IEMl5K, HV_BINOP_MULTIPLY, 0, m, &cBinop_F7IEMl5K_sendMessage);
}

void Heavy_ChaffVerb::cMsg_vSXwdg7D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_hh1XRNom, 0, m, &cDelay_hh1XRNom_sendMessage);
}

void Heavy_ChaffVerb::cBinop_P2IIN5Y6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_hh1XRNom, 2, m, &cDelay_hh1XRNom_sendMessage);
}

void Heavy_ChaffVerb::cBinop_VuOqOlSQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_F7IEMl5K, HV_BINOP_MULTIPLY, 1, m, &cBinop_F7IEMl5K_sendMessage);
}

void Heavy_ChaffVerb::cBinop_F7IEMl5K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_P2IIN5Y6_sendMessage);
}

void Heavy_ChaffVerb::cTabhead_RyvU3PWU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QKiI0lXT, HV_BINOP_SUBTRACT, 0, m, &cBinop_QKiI0lXT_sendMessage);
}

void Heavy_ChaffVerb::cMsg_0P5vgpcP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_EJO9vYMV_sendMessage);
}

void Heavy_ChaffVerb::cSystem_EJO9vYMV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_2gGgcCnB_sendMessage);
}

void Heavy_ChaffVerb::cVar_mo2tx1bc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1TskSZY8_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_tANuq7nv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_tANuq7nv, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Y14zDpbB, 0, m, &cDelay_Y14zDpbB_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_7WDI4aPT, 0, m, &sTabread_7WDI4aPT_sendMessage);
}

void Heavy_ChaffVerb::cDelay_Y14zDpbB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Y14zDpbB, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_7WDI4aPT, 0, m, &sTabread_7WDI4aPT_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Y14zDpbB, 0, m, &cDelay_Y14zDpbB_sendMessage);
}

void Heavy_ChaffVerb::sTabread_7WDI4aPT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_wVosukry, HV_BINOP_SUBTRACT, 0, m, &cBinop_wVosukry_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_WW6EYeT6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_unSoMnmn, HV_BINOP_MAX, 0, m, &cBinop_unSoMnmn_sendMessage);
}

void Heavy_ChaffVerb::cBinop_2gGgcCnB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WW6EYeT6, HV_BINOP_MULTIPLY, 0, m, &cBinop_WW6EYeT6_sendMessage);
}

void Heavy_ChaffVerb::cBinop_QKiI0lXT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pmTP0Iiy_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_7WDI4aPT, 0, m, &sTabread_7WDI4aPT_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_m3ZBCCgP_sendMessage);
}

void Heavy_ChaffVerb::cSystem_hWPRxikF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wVosukry, HV_BINOP_SUBTRACT, 1, m, &cBinop_wVosukry_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Y14zDpbB, 2, m, &cDelay_Y14zDpbB_sendMessage);
}

void Heavy_ChaffVerb::cMsg_1TskSZY8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_hWPRxikF_sendMessage);
}

void Heavy_ChaffVerb::cMsg_pmTP0Iiy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_tANuq7nv, 0, m, &cDelay_tANuq7nv_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Y14zDpbB, 0, m, &cDelay_Y14zDpbB_sendMessage);
}

void Heavy_ChaffVerb::cMsg_js9ocMJ9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_unSoMnmn, HV_BINOP_MAX, 1, m, &cBinop_unSoMnmn_sendMessage);
}

void Heavy_ChaffVerb::cBinop_unSoMnmn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QKiI0lXT, HV_BINOP_SUBTRACT, 1, m, &cBinop_QKiI0lXT_sendMessage);
}

void Heavy_ChaffVerb::cCast_m3ZBCCgP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_tANuq7nv, 0, m, &cDelay_tANuq7nv_sendMessage);
}

void Heavy_ChaffVerb::cBinop_emwTLRkT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_tANuq7nv, 2, m, &cDelay_tANuq7nv_sendMessage);
}

void Heavy_ChaffVerb::cBinop_wVosukry_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_emwTLRkT_sendMessage);
}

void Heavy_ChaffVerb::cCast_y5ixSXe0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_mo2tx1bc, 0, m, &cVar_mo2tx1bc_sendMessage);
  cMsg_0P5vgpcP_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_RyvU3PWU, 0, m, &cTabhead_RyvU3PWU_sendMessage);
}

void Heavy_ChaffVerb::cTabhead_zSf3h4nV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ngbybU9Y, HV_BINOP_SUBTRACT, 0, m, &cBinop_ngbybU9Y_sendMessage);
}

void Heavy_ChaffVerb::cMsg_rAC3e481_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_wU9Rjicz_sendMessage);
}

void Heavy_ChaffVerb::cSystem_wU9Rjicz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_z65MOAwy_sendMessage);
}

void Heavy_ChaffVerb::cVar_0mzy8eyX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SV57oNHS_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_9Pr7Ek75_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_9Pr7Ek75, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_h5VUqwyU, 0, m, &cDelay_h5VUqwyU_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_gnHu58Jr, 0, m, &sTabread_gnHu58Jr_sendMessage);
}

void Heavy_ChaffVerb::cDelay_h5VUqwyU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_h5VUqwyU, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_gnHu58Jr, 0, m, &sTabread_gnHu58Jr_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_h5VUqwyU, 0, m, &cDelay_h5VUqwyU_sendMessage);
}

void Heavy_ChaffVerb::sTabread_gnHu58Jr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_VQMZqIW9, HV_BINOP_SUBTRACT, 0, m, &cBinop_VQMZqIW9_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_9t3WLXc7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4m26YLAm, HV_BINOP_MAX, 0, m, &cBinop_4m26YLAm_sendMessage);
}

void Heavy_ChaffVerb::cBinop_z65MOAwy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9t3WLXc7, HV_BINOP_MULTIPLY, 0, m, &cBinop_9t3WLXc7_sendMessage);
}

void Heavy_ChaffVerb::cBinop_ngbybU9Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FSKiNJhp_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_gnHu58Jr, 0, m, &sTabread_gnHu58Jr_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_J5kMFcaC_sendMessage);
}

void Heavy_ChaffVerb::cSystem_YzBMarQ7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VQMZqIW9, HV_BINOP_SUBTRACT, 1, m, &cBinop_VQMZqIW9_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_h5VUqwyU, 2, m, &cDelay_h5VUqwyU_sendMessage);
}

void Heavy_ChaffVerb::cMsg_SV57oNHS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_YzBMarQ7_sendMessage);
}

void Heavy_ChaffVerb::cMsg_FSKiNJhp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_9Pr7Ek75, 0, m, &cDelay_9Pr7Ek75_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_h5VUqwyU, 0, m, &cDelay_h5VUqwyU_sendMessage);
}

void Heavy_ChaffVerb::cMsg_bTVrJWjP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_4m26YLAm, HV_BINOP_MAX, 1, m, &cBinop_4m26YLAm_sendMessage);
}

void Heavy_ChaffVerb::cBinop_4m26YLAm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ngbybU9Y, HV_BINOP_SUBTRACT, 1, m, &cBinop_ngbybU9Y_sendMessage);
}

void Heavy_ChaffVerb::cCast_J5kMFcaC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_9Pr7Ek75, 0, m, &cDelay_9Pr7Ek75_sendMessage);
}

void Heavy_ChaffVerb::cBinop_SodMJ3yV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_9Pr7Ek75, 2, m, &cDelay_9Pr7Ek75_sendMessage);
}

void Heavy_ChaffVerb::cBinop_VQMZqIW9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_SodMJ3yV_sendMessage);
}

void Heavy_ChaffVerb::cCast_OPjRIjz6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0mzy8eyX, 0, m, &cVar_0mzy8eyX_sendMessage);
  cMsg_rAC3e481_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_zSf3h4nV, 0, m, &cTabhead_zSf3h4nV_sendMessage);
}

void Heavy_ChaffVerb::cTabhead_vf8MpW5m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XAvvCIcu, HV_BINOP_SUBTRACT, 0, m, &cBinop_XAvvCIcu_sendMessage);
}

void Heavy_ChaffVerb::cMsg_GYMUQXhZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_moMBXc3X_sendMessage);
}

void Heavy_ChaffVerb::cSystem_moMBXc3X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_25RvDVAh_sendMessage);
}

void Heavy_ChaffVerb::cVar_69EXG7nV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ucG4NQD0_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_mcJreT0g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_mcJreT0g, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_q4EyuiUV, 0, m, &cDelay_q4EyuiUV_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_ahU3pB3H, 0, m, &sTabread_ahU3pB3H_sendMessage);
}

void Heavy_ChaffVerb::cDelay_q4EyuiUV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_q4EyuiUV, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_ahU3pB3H, 0, m, &sTabread_ahU3pB3H_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_q4EyuiUV, 0, m, &cDelay_q4EyuiUV_sendMessage);
}

void Heavy_ChaffVerb::sTabread_ahU3pB3H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_uD7FpctD, HV_BINOP_SUBTRACT, 0, m, &cBinop_uD7FpctD_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_AIQf7Yog_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_J66uIDKs, HV_BINOP_MAX, 0, m, &cBinop_J66uIDKs_sendMessage);
}

void Heavy_ChaffVerb::cBinop_25RvDVAh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AIQf7Yog, HV_BINOP_MULTIPLY, 0, m, &cBinop_AIQf7Yog_sendMessage);
}

void Heavy_ChaffVerb::cBinop_XAvvCIcu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jwrLRfLM_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_ahU3pB3H, 0, m, &sTabread_ahU3pB3H_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ulIpByH3_sendMessage);
}

void Heavy_ChaffVerb::cSystem_IqnONscG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uD7FpctD, HV_BINOP_SUBTRACT, 1, m, &cBinop_uD7FpctD_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_q4EyuiUV, 2, m, &cDelay_q4EyuiUV_sendMessage);
}

void Heavy_ChaffVerb::cMsg_ucG4NQD0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_IqnONscG_sendMessage);
}

void Heavy_ChaffVerb::cMsg_jwrLRfLM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_mcJreT0g, 0, m, &cDelay_mcJreT0g_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_q4EyuiUV, 0, m, &cDelay_q4EyuiUV_sendMessage);
}

void Heavy_ChaffVerb::cMsg_DesWvglX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_J66uIDKs, HV_BINOP_MAX, 1, m, &cBinop_J66uIDKs_sendMessage);
}

void Heavy_ChaffVerb::cBinop_J66uIDKs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XAvvCIcu, HV_BINOP_SUBTRACT, 1, m, &cBinop_XAvvCIcu_sendMessage);
}

void Heavy_ChaffVerb::cCast_ulIpByH3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_mcJreT0g, 0, m, &cDelay_mcJreT0g_sendMessage);
}

void Heavy_ChaffVerb::cBinop_ATbNID9k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_mcJreT0g, 2, m, &cDelay_mcJreT0g_sendMessage);
}

void Heavy_ChaffVerb::cBinop_uD7FpctD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_ATbNID9k_sendMessage);
}

void Heavy_ChaffVerb::cCast_LyaKhQMp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_69EXG7nV, 0, m, &cVar_69EXG7nV_sendMessage);
  cMsg_GYMUQXhZ_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_vf8MpW5m, 0, m, &cTabhead_vf8MpW5m_sendMessage);
}

void Heavy_ChaffVerb::cTabhead_5US86sJf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BhevXLae, HV_BINOP_SUBTRACT, 0, m, &cBinop_BhevXLae_sendMessage);
}

void Heavy_ChaffVerb::cMsg_UOcZqbQ5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_hxVsI4jo_sendMessage);
}

void Heavy_ChaffVerb::cSystem_hxVsI4jo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_1433xGbf_sendMessage);
}

void Heavy_ChaffVerb::cVar_8HGBrpHJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gzRXyJF6_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_3rq7jeOh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_3rq7jeOh, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Vlmo2uCI, 0, m, &cDelay_Vlmo2uCI_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_yqQ1pdWX, 0, m, &sTabread_yqQ1pdWX_sendMessage);
}

void Heavy_ChaffVerb::cDelay_Vlmo2uCI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Vlmo2uCI, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_yqQ1pdWX, 0, m, &sTabread_yqQ1pdWX_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Vlmo2uCI, 0, m, &cDelay_Vlmo2uCI_sendMessage);
}

void Heavy_ChaffVerb::sTabread_yqQ1pdWX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_MsCyD43p, HV_BINOP_SUBTRACT, 0, m, &cBinop_MsCyD43p_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_vti4IXZx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QSDg3Br6, HV_BINOP_MAX, 0, m, &cBinop_QSDg3Br6_sendMessage);
}

void Heavy_ChaffVerb::cBinop_1433xGbf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vti4IXZx, HV_BINOP_MULTIPLY, 0, m, &cBinop_vti4IXZx_sendMessage);
}

void Heavy_ChaffVerb::cBinop_BhevXLae_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_V8wfYImk_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_yqQ1pdWX, 0, m, &sTabread_yqQ1pdWX_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NftGwHIw_sendMessage);
}

void Heavy_ChaffVerb::cSystem_Kf98KrFl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MsCyD43p, HV_BINOP_SUBTRACT, 1, m, &cBinop_MsCyD43p_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Vlmo2uCI, 2, m, &cDelay_Vlmo2uCI_sendMessage);
}

void Heavy_ChaffVerb::cMsg_gzRXyJF6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Kf98KrFl_sendMessage);
}

void Heavy_ChaffVerb::cMsg_V8wfYImk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_3rq7jeOh, 0, m, &cDelay_3rq7jeOh_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Vlmo2uCI, 0, m, &cDelay_Vlmo2uCI_sendMessage);
}

void Heavy_ChaffVerb::cMsg_y8f3BIVC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_QSDg3Br6, HV_BINOP_MAX, 1, m, &cBinop_QSDg3Br6_sendMessage);
}

void Heavy_ChaffVerb::cBinop_QSDg3Br6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BhevXLae, HV_BINOP_SUBTRACT, 1, m, &cBinop_BhevXLae_sendMessage);
}

void Heavy_ChaffVerb::cCast_NftGwHIw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_3rq7jeOh, 0, m, &cDelay_3rq7jeOh_sendMessage);
}

void Heavy_ChaffVerb::cBinop_MQMBsB86_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_3rq7jeOh, 2, m, &cDelay_3rq7jeOh_sendMessage);
}

void Heavy_ChaffVerb::cBinop_MsCyD43p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_MQMBsB86_sendMessage);
}

void Heavy_ChaffVerb::cCast_4x7aoK4F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_8HGBrpHJ, 0, m, &cVar_8HGBrpHJ_sendMessage);
  cMsg_UOcZqbQ5_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_5US86sJf, 0, m, &cTabhead_5US86sJf_sendMessage);
}

void Heavy_ChaffVerb::cMsg_nEKxjg0E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_O2lsDxPf_sendMessage);
}

void Heavy_ChaffVerb::cSystem_O2lsDxPf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_mwECx5Ri_sendMessage);
}

void Heavy_ChaffVerb::cDelay_NCPv6bNF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_NCPv6bNF, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_d1rLeWNE, 0, m, &cDelay_d1rLeWNE_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_NCPv6bNF, 0, m, &cDelay_NCPv6bNF_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_5dVdSzOB, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_d1rLeWNE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_d1rLeWNE, m);
  cMsg_CVkPdaSh_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_IVaEtVmB_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_M1DsGnOj_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_Z0DpcWeG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7KriPh05_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_NyaIKUQ5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TlpisHxN_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_NCPv6bNF, 2, m, &cDelay_NCPv6bNF_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3adVwEPz_sendMessage);
}

void Heavy_ChaffVerb::cMsg_7KriPh05_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_NyaIKUQ5, 0, m, &hTable_NyaIKUQ5_sendMessage);
}

void Heavy_ChaffVerb::cBinop_mwECx5Ri_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 58.6435f, 0, m, &cBinop_Z0DpcWeG_sendMessage);
}

void Heavy_ChaffVerb::cMsg_CVkPdaSh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_NyaIKUQ5, 0, m, &hTable_NyaIKUQ5_sendMessage);
}

void Heavy_ChaffVerb::cCast_3adVwEPz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_NCPv6bNF, 0, m, &cDelay_NCPv6bNF_sendMessage);
}

void Heavy_ChaffVerb::cMsg_TlpisHxN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_d1rLeWNE, 2, m, &cDelay_d1rLeWNE_sendMessage);
}

void Heavy_ChaffVerb::cMsg_M1DsGnOj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_5dVdSzOB, 1, m, NULL);
}

void Heavy_ChaffVerb::cMsg_A5Xq5rVo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_mKUKIJ8B_sendMessage);
}

void Heavy_ChaffVerb::cSystem_mKUKIJ8B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_XHaKGXgM_sendMessage);
}

void Heavy_ChaffVerb::cDelay_dx1msDw6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_dx1msDw6, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_dspepbfs, 0, m, &cDelay_dspepbfs_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_dx1msDw6, 0, m, &cDelay_dx1msDw6_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_c2DjzXtG, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_dspepbfs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_dspepbfs, m);
  cMsg_L3mJ0OFi_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_9mv8gZpM_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_TpSbmrku_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_TNErpEws_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_z6i7R8n4_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_TaWDj5vU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_W4u6QXEb_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_dx1msDw6, 2, m, &cDelay_dx1msDw6_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hrJHuUbS_sendMessage);
}

void Heavy_ChaffVerb::cMsg_z6i7R8n4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_TaWDj5vU, 0, m, &hTable_TaWDj5vU_sendMessage);
}

void Heavy_ChaffVerb::cBinop_XHaKGXgM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 69.4325f, 0, m, &cBinop_TNErpEws_sendMessage);
}

void Heavy_ChaffVerb::cMsg_L3mJ0OFi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_TaWDj5vU, 0, m, &hTable_TaWDj5vU_sendMessage);
}

void Heavy_ChaffVerb::cCast_hrJHuUbS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_dx1msDw6, 0, m, &cDelay_dx1msDw6_sendMessage);
}

void Heavy_ChaffVerb::cMsg_W4u6QXEb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_dspepbfs, 2, m, &cDelay_dspepbfs_sendMessage);
}

void Heavy_ChaffVerb::cMsg_TpSbmrku_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_c2DjzXtG, 1, m, NULL);
}

void Heavy_ChaffVerb::cMsg_MeztCBe7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_hjiRaiSa_sendMessage);
}

void Heavy_ChaffVerb::cSystem_hjiRaiSa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_nypV30ro_sendMessage);
}

void Heavy_ChaffVerb::cDelay_fpffzd1Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_fpffzd1Q, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_WlUfMvGQ, 0, m, &cDelay_WlUfMvGQ_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_fpffzd1Q, 0, m, &cDelay_fpffzd1Q_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_jnLSUggd, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_WlUfMvGQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_WlUfMvGQ, m);
  cMsg_U4a9Fyxl_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_XWszj0vq_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_TxMCk2nh_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_16OjkEsf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bHesDRxt_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_fiQE0RI9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hU4CVmr9_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_fpffzd1Q, 2, m, &cDelay_fpffzd1Q_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7w7al49x_sendMessage);
}

void Heavy_ChaffVerb::cMsg_bHesDRxt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_fiQE0RI9, 0, m, &hTable_fiQE0RI9_sendMessage);
}

void Heavy_ChaffVerb::cBinop_nypV30ro_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 74.5234f, 0, m, &cBinop_16OjkEsf_sendMessage);
}

void Heavy_ChaffVerb::cMsg_U4a9Fyxl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_fiQE0RI9, 0, m, &hTable_fiQE0RI9_sendMessage);
}

void Heavy_ChaffVerb::cCast_7w7al49x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_fpffzd1Q, 0, m, &cDelay_fpffzd1Q_sendMessage);
}

void Heavy_ChaffVerb::cMsg_hU4CVmr9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_WlUfMvGQ, 2, m, &cDelay_WlUfMvGQ_sendMessage);
}

void Heavy_ChaffVerb::cMsg_TxMCk2nh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_jnLSUggd, 1, m, NULL);
}

void Heavy_ChaffVerb::cMsg_eX4RuWyx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_S2TsBeuA_sendMessage);
}

void Heavy_ChaffVerb::cSystem_S2TsBeuA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_XCVRBpPh_sendMessage);
}

void Heavy_ChaffVerb::cDelay_ZWiuDD3z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ZWiuDD3z, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_uU8dmnaQ, 0, m, &cDelay_uU8dmnaQ_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ZWiuDD3z, 0, m, &cDelay_ZWiuDD3z_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_ol5QyNWW, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_uU8dmnaQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_uU8dmnaQ, m);
  cMsg_hUEjhShc_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_n9pfLqKV_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_zpaHsUfr_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_fjRPTOkO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Ym2E62CX_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_IN7rXJDL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_M3svxXXh_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ZWiuDD3z, 2, m, &cDelay_ZWiuDD3z_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uiuCM59r_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Ym2E62CX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_IN7rXJDL, 0, m, &hTable_IN7rXJDL_sendMessage);
}

void Heavy_ChaffVerb::cBinop_XCVRBpPh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 86.1244f, 0, m, &cBinop_fjRPTOkO_sendMessage);
}

void Heavy_ChaffVerb::cMsg_hUEjhShc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_IN7rXJDL, 0, m, &hTable_IN7rXJDL_sendMessage);
}

void Heavy_ChaffVerb::cCast_uiuCM59r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ZWiuDD3z, 0, m, &cDelay_ZWiuDD3z_sendMessage);
}

void Heavy_ChaffVerb::cMsg_M3svxXXh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_uU8dmnaQ, 2, m, &cDelay_uU8dmnaQ_sendMessage);
}

void Heavy_ChaffVerb::cMsg_zpaHsUfr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_ol5QyNWW, 1, m, NULL);
}

void Heavy_ChaffVerb::cPack_fGt1YB7V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sLine_onMessage(_c, &Context(_c)->sLine_ix9qJEoG, 0, m, NULL);
}

void Heavy_ChaffVerb::cPack_p7zoaMGB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sLine_onMessage(_c, &Context(_c)->sLine_B8tHs58F, 0, m, NULL);
}

void Heavy_ChaffVerb::cBinop_R9kZxlyu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_8VRF0PXU_sendMessage);
}

void Heavy_ChaffVerb::cBinop_8VRF0PXU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 200.0f, 0, m, &cBinop_3WyssFfY_sendMessage);
}

void Heavy_ChaffVerb::cVar_fXgFpsF0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vsjCPcsV, HV_BINOP_MULTIPLY, 0, m, &cBinop_vsjCPcsV_sendMessage);
}

void Heavy_ChaffVerb::cMsg_qiX0MTKJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_PLtnZ0NI_sendMessage);
}

void Heavy_ChaffVerb::cSystem_PLtnZ0NI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_v81Ap0tl_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_vsjCPcsV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_b7pb31ER_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Wjsuyo9Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vsjCPcsV, HV_BINOP_MULTIPLY, 1, m, &cBinop_vsjCPcsV_sendMessage);
}

void Heavy_ChaffVerb::cMsg_v81Ap0tl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_Wjsuyo9Z_sendMessage);
}

void Heavy_ChaffVerb::cBinop_b7pb31ER_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_YmlnAKch_sendMessage);
}

void Heavy_ChaffVerb::cBinop_YmlnAKch_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_AumYwmke_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_BcSoIBbs, m);
}

void Heavy_ChaffVerb::cBinop_AumYwmke_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_J6Ap7flw, m);
}

void Heavy_ChaffVerb::cVar_oHnXd3cT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.125f, 0, m, &cBinop_s7raUbIz_sendMessage);
}

void Heavy_ChaffVerb::cVar_1eWsxQMS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_R9kZxlyu_sendMessage);
}

void Heavy_ChaffVerb::cVar_YCMr5MlE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN_EQL, 1.0f, 0, m, &cBinop_f0BvQ0cr_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_7rVdvtEL, 0, m, &cIf_7rVdvtEL_sendMessage);
}

void Heavy_ChaffVerb::cVar_oFdrLCII_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_ulY4nDMa_sendMessage);
}

void Heavy_ChaffVerb::cIf_7rVdvtEL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_zXqbnH9g_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_DUmfrq7l, 0, m, &cVar_DUmfrq7l_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_f0BvQ0cr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7rVdvtEL, 1, m, &cIf_7rVdvtEL_sendMessage);
}

void Heavy_ChaffVerb::cBinop_ulY4nDMa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_kw6fgnQ1_sendMessage);
}

void Heavy_ChaffVerb::cBinop_kw6fgnQ1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_KakEh7GG, 0, m, &cVar_KakEh7GG_sendMessage);
}

void Heavy_ChaffVerb::cMsg_5mTy0jtd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Q01c1J1g_sendMessage);
}

void Heavy_ChaffVerb::cSystem_Q01c1J1g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_UkvSUk4n_sendMessage);
}

void Heavy_ChaffVerb::cDelay_RQGpujiK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_RQGpujiK, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_lsUvLvH5, 0, m, &cDelay_lsUvLvH5_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_RQGpujiK, 0, m, &cDelay_RQGpujiK_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_bQeLtBe0, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_lsUvLvH5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_lsUvLvH5, m);
  cMsg_QfVlNivs_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_WqmOdgx9_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_mIDNAfbG_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_6XCdT3Nk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FnW8Vmlm_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_bqTOuW1T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pvc0xn2L_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_RQGpujiK, 2, m, &cDelay_RQGpujiK_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ooY0lGvQ_sendMessage);
}

void Heavy_ChaffVerb::cMsg_FnW8Vmlm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_bqTOuW1T, 0, m, &hTable_bqTOuW1T_sendMessage);
}

void Heavy_ChaffVerb::cBinop_UkvSUk4n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 43.5337f, 0, m, &cBinop_6XCdT3Nk_sendMessage);
}

void Heavy_ChaffVerb::cMsg_QfVlNivs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_bqTOuW1T, 0, m, &hTable_bqTOuW1T_sendMessage);
}

void Heavy_ChaffVerb::cCast_ooY0lGvQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_RQGpujiK, 0, m, &cDelay_RQGpujiK_sendMessage);
}

void Heavy_ChaffVerb::cMsg_pvc0xn2L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_lsUvLvH5, 2, m, &cDelay_lsUvLvH5_sendMessage);
}

void Heavy_ChaffVerb::cMsg_mIDNAfbG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_bQeLtBe0, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_vZBCvVpQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7ltIfhPY, HV_BINOP_SUBTRACT, 0, m, &cBinop_7ltIfhPY_sendMessage);
}

void Heavy_ChaffVerb::cMsg_mzR6UhGa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_VAN1BpLR_sendMessage);
}

void Heavy_ChaffVerb::cSystem_VAN1BpLR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_eRYlguxa_sendMessage);
}

void Heavy_ChaffVerb::cVar_SVESKeA9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cKH6vio6_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_KSGWjcsZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_KSGWjcsZ, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_qb3xAJ8Y, 0, m, &cDelay_qb3xAJ8Y_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_5vBrt5Lt, 0, m, &sTabread_5vBrt5Lt_sendMessage);
}

void Heavy_ChaffVerb::cDelay_qb3xAJ8Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_qb3xAJ8Y, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_5vBrt5Lt, 0, m, &sTabread_5vBrt5Lt_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_qb3xAJ8Y, 0, m, &cDelay_qb3xAJ8Y_sendMessage);
}

void Heavy_ChaffVerb::sTabread_5vBrt5Lt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_7DiKtxrs, HV_BINOP_SUBTRACT, 0, m, &cBinop_7DiKtxrs_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_awaRR0nD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QsKJCxh9, HV_BINOP_MAX, 0, m, &cBinop_QsKJCxh9_sendMessage);
}

void Heavy_ChaffVerb::cBinop_eRYlguxa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_awaRR0nD, HV_BINOP_MULTIPLY, 0, m, &cBinop_awaRR0nD_sendMessage);
}

void Heavy_ChaffVerb::cBinop_7ltIfhPY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HNwmL3mH_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_5vBrt5Lt, 0, m, &sTabread_5vBrt5Lt_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VWMplb6T_sendMessage);
}

void Heavy_ChaffVerb::cSystem_YiL2K4jf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7DiKtxrs, HV_BINOP_SUBTRACT, 1, m, &cBinop_7DiKtxrs_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_qb3xAJ8Y, 2, m, &cDelay_qb3xAJ8Y_sendMessage);
}

void Heavy_ChaffVerb::cMsg_cKH6vio6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_YiL2K4jf_sendMessage);
}

void Heavy_ChaffVerb::cMsg_HNwmL3mH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_KSGWjcsZ, 0, m, &cDelay_KSGWjcsZ_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_qb3xAJ8Y, 0, m, &cDelay_qb3xAJ8Y_sendMessage);
}

void Heavy_ChaffVerb::cMsg_0QI0Hm3F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_QsKJCxh9, HV_BINOP_MAX, 1, m, &cBinop_QsKJCxh9_sendMessage);
}

void Heavy_ChaffVerb::cBinop_QsKJCxh9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7ltIfhPY, HV_BINOP_SUBTRACT, 1, m, &cBinop_7ltIfhPY_sendMessage);
}

void Heavy_ChaffVerb::cCast_VWMplb6T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_KSGWjcsZ, 0, m, &cDelay_KSGWjcsZ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_NydIxXys_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_KSGWjcsZ, 2, m, &cDelay_KSGWjcsZ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_7DiKtxrs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_NydIxXys_sendMessage);
}

void Heavy_ChaffVerb::cCast_4ODLDtNQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_SVESKeA9, 0, m, &cVar_SVESKeA9_sendMessage);
  cMsg_mzR6UhGa_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_vZBCvVpQ, 0, m, &cTabhead_vZBCvVpQ_sendMessage);
}

void Heavy_ChaffVerb::cMsg_d17bD3vA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_g0XbUpo1_sendMessage);
}

void Heavy_ChaffVerb::cSystem_g0XbUpo1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_H8zhJ6Au_sendMessage);
}

void Heavy_ChaffVerb::cDelay_fbi0B0Rm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_fbi0B0Rm, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_bpEKovGk, 0, m, &cDelay_bpEKovGk_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_fbi0B0Rm, 0, m, &cDelay_fbi0B0Rm_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_G4XvBQ0b, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_bpEKovGk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_bpEKovGk, m);
  cMsg_Ee5bAFqc_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_YdxmaaiC_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_rD3YMsOK_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_F0FYCCPI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4D9DdYKd_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_r3HfJ7py_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Y3OhEuzt_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_fbi0B0Rm, 2, m, &cDelay_fbi0B0Rm_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OveIYYWw_sendMessage);
}

void Heavy_ChaffVerb::cMsg_4D9DdYKd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_r3HfJ7py, 0, m, &hTable_r3HfJ7py_sendMessage);
}

void Heavy_ChaffVerb::cBinop_H8zhJ6Au_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 25.796f, 0, m, &cBinop_F0FYCCPI_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Ee5bAFqc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_r3HfJ7py, 0, m, &hTable_r3HfJ7py_sendMessage);
}

void Heavy_ChaffVerb::cCast_OveIYYWw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_fbi0B0Rm, 0, m, &cDelay_fbi0B0Rm_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Y3OhEuzt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_bpEKovGk, 2, m, &cDelay_bpEKovGk_sendMessage);
}

void Heavy_ChaffVerb::cMsg_rD3YMsOK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_G4XvBQ0b, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_InAl9VQU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZoSNL2cD, HV_BINOP_SUBTRACT, 0, m, &cBinop_ZoSNL2cD_sendMessage);
}

void Heavy_ChaffVerb::cMsg_r4UnVSPQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_mTxKAFNt_sendMessage);
}

void Heavy_ChaffVerb::cSystem_mTxKAFNt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_okAmcYku_sendMessage);
}

void Heavy_ChaffVerb::cVar_pKC0yOrJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_STctAfcE_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_1P2N4euC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_1P2N4euC, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_BlrgKH5W, 0, m, &cDelay_BlrgKH5W_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_1Kl3wrmP, 0, m, &sTabread_1Kl3wrmP_sendMessage);
}

void Heavy_ChaffVerb::cDelay_BlrgKH5W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_BlrgKH5W, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_1Kl3wrmP, 0, m, &sTabread_1Kl3wrmP_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_BlrgKH5W, 0, m, &cDelay_BlrgKH5W_sendMessage);
}

void Heavy_ChaffVerb::sTabread_1Kl3wrmP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_7yfIhw8I, HV_BINOP_SUBTRACT, 0, m, &cBinop_7yfIhw8I_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_147p8vxa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GsOvjG74, HV_BINOP_MAX, 0, m, &cBinop_GsOvjG74_sendMessage);
}

void Heavy_ChaffVerb::cBinop_okAmcYku_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_147p8vxa, HV_BINOP_MULTIPLY, 0, m, &cBinop_147p8vxa_sendMessage);
}

void Heavy_ChaffVerb::cBinop_ZoSNL2cD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8XwmKgKG_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_1Kl3wrmP, 0, m, &sTabread_1Kl3wrmP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_79NQx7tE_sendMessage);
}

void Heavy_ChaffVerb::cSystem_3ouGvdjy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7yfIhw8I, HV_BINOP_SUBTRACT, 1, m, &cBinop_7yfIhw8I_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_BlrgKH5W, 2, m, &cDelay_BlrgKH5W_sendMessage);
}

void Heavy_ChaffVerb::cMsg_STctAfcE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_3ouGvdjy_sendMessage);
}

void Heavy_ChaffVerb::cMsg_8XwmKgKG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_1P2N4euC, 0, m, &cDelay_1P2N4euC_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_BlrgKH5W, 0, m, &cDelay_BlrgKH5W_sendMessage);
}

void Heavy_ChaffVerb::cMsg_CCWFnRev_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_GsOvjG74, HV_BINOP_MAX, 1, m, &cBinop_GsOvjG74_sendMessage);
}

void Heavy_ChaffVerb::cBinop_GsOvjG74_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZoSNL2cD, HV_BINOP_SUBTRACT, 1, m, &cBinop_ZoSNL2cD_sendMessage);
}

void Heavy_ChaffVerb::cCast_79NQx7tE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_1P2N4euC, 0, m, &cDelay_1P2N4euC_sendMessage);
}

void Heavy_ChaffVerb::cBinop_xHgsX0eh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_1P2N4euC, 2, m, &cDelay_1P2N4euC_sendMessage);
}

void Heavy_ChaffVerb::cBinop_7yfIhw8I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_xHgsX0eh_sendMessage);
}

void Heavy_ChaffVerb::cCast_3B48hbU1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_pKC0yOrJ, 0, m, &cVar_pKC0yOrJ_sendMessage);
  cMsg_r4UnVSPQ_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_InAl9VQU, 0, m, &cTabhead_InAl9VQU_sendMessage);
}

void Heavy_ChaffVerb::cMsg_dth16pqW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_dvc1U895_sendMessage);
}

void Heavy_ChaffVerb::cSystem_dvc1U895_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_RnkMpjD8_sendMessage);
}

void Heavy_ChaffVerb::cDelay_gDTCkO7J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_gDTCkO7J, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_01d4wnzX, 0, m, &cDelay_01d4wnzX_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_gDTCkO7J, 0, m, &cDelay_gDTCkO7J_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_WHZaySni, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_01d4wnzX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_01d4wnzX, m);
  cMsg_ylFWaZcJ_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_s0T6mWJd_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_6shmyWmg_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_ApRGEhtz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Qcs6OTOR_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_WsrASp2G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dlTpAP74_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_gDTCkO7J, 2, m, &cDelay_gDTCkO7J_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_O15LUF2a_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Qcs6OTOR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_WsrASp2G, 0, m, &hTable_WsrASp2G_sendMessage);
}

void Heavy_ChaffVerb::cBinop_RnkMpjD8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 19.392f, 0, m, &cBinop_ApRGEhtz_sendMessage);
}

void Heavy_ChaffVerb::cMsg_ylFWaZcJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_WsrASp2G, 0, m, &hTable_WsrASp2G_sendMessage);
}

void Heavy_ChaffVerb::cCast_O15LUF2a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_gDTCkO7J, 0, m, &cDelay_gDTCkO7J_sendMessage);
}

void Heavy_ChaffVerb::cMsg_dlTpAP74_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_01d4wnzX, 2, m, &cDelay_01d4wnzX_sendMessage);
}

void Heavy_ChaffVerb::cMsg_6shmyWmg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_WHZaySni, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_8W3uz42X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7N5gIPIH, HV_BINOP_SUBTRACT, 0, m, &cBinop_7N5gIPIH_sendMessage);
}

void Heavy_ChaffVerb::cMsg_bLOhHLEk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_SgHMrHGu_sendMessage);
}

void Heavy_ChaffVerb::cSystem_SgHMrHGu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_sHEf5Dti_sendMessage);
}

void Heavy_ChaffVerb::cVar_y7ej96da_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hm3h4owI_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_pOqwfQJx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_pOqwfQJx, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_9llx5H16, 0, m, &cDelay_9llx5H16_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_cLcPVf2T, 0, m, &sTabread_cLcPVf2T_sendMessage);
}

void Heavy_ChaffVerb::cDelay_9llx5H16_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_9llx5H16, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_cLcPVf2T, 0, m, &sTabread_cLcPVf2T_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_9llx5H16, 0, m, &cDelay_9llx5H16_sendMessage);
}

void Heavy_ChaffVerb::sTabread_cLcPVf2T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_is2HBZhF, HV_BINOP_SUBTRACT, 0, m, &cBinop_is2HBZhF_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_TzDSvkz4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tZ30gduz, HV_BINOP_MAX, 0, m, &cBinop_tZ30gduz_sendMessage);
}

void Heavy_ChaffVerb::cBinop_sHEf5Dti_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TzDSvkz4, HV_BINOP_MULTIPLY, 0, m, &cBinop_TzDSvkz4_sendMessage);
}

void Heavy_ChaffVerb::cBinop_7N5gIPIH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_V67kaAyb_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_cLcPVf2T, 0, m, &sTabread_cLcPVf2T_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CrnpEosf_sendMessage);
}

void Heavy_ChaffVerb::cSystem_2inrRmhr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_is2HBZhF, HV_BINOP_SUBTRACT, 1, m, &cBinop_is2HBZhF_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_9llx5H16, 2, m, &cDelay_9llx5H16_sendMessage);
}

void Heavy_ChaffVerb::cMsg_hm3h4owI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_2inrRmhr_sendMessage);
}

void Heavy_ChaffVerb::cMsg_V67kaAyb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_pOqwfQJx, 0, m, &cDelay_pOqwfQJx_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_9llx5H16, 0, m, &cDelay_9llx5H16_sendMessage);
}

void Heavy_ChaffVerb::cMsg_RnDDQVCT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_tZ30gduz, HV_BINOP_MAX, 1, m, &cBinop_tZ30gduz_sendMessage);
}

void Heavy_ChaffVerb::cBinop_tZ30gduz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7N5gIPIH, HV_BINOP_SUBTRACT, 1, m, &cBinop_7N5gIPIH_sendMessage);
}

void Heavy_ChaffVerb::cCast_CrnpEosf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_pOqwfQJx, 0, m, &cDelay_pOqwfQJx_sendMessage);
}

void Heavy_ChaffVerb::cBinop_WeajDe2r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_pOqwfQJx, 2, m, &cDelay_pOqwfQJx_sendMessage);
}

void Heavy_ChaffVerb::cBinop_is2HBZhF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_WeajDe2r_sendMessage);
}

void Heavy_ChaffVerb::cCast_DjGRS027_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_y7ej96da, 0, m, &cVar_y7ej96da_sendMessage);
  cMsg_bLOhHLEk_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_8W3uz42X, 0, m, &cTabhead_8W3uz42X_sendMessage);
}

void Heavy_ChaffVerb::cMsg_mCRTHbrl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_5Ad9OzUe_sendMessage);
}

void Heavy_ChaffVerb::cSystem_5Ad9OzUe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_Cs25OqnJ_sendMessage);
}

void Heavy_ChaffVerb::cDelay_cv7vDQxw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_cv7vDQxw, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_TPHicpsP, 0, m, &cDelay_TPHicpsP_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_cv7vDQxw, 0, m, &cDelay_cv7vDQxw_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_S9UN3mKO, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_TPHicpsP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_TPHicpsP, m);
  cMsg_jC2Qh6ox_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_LvsAZxv0_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_hv4oBJtn_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_D9V8Elwk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tKZKAusT_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_giTLcA7T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UF7rC9le_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_cv7vDQxw, 2, m, &cDelay_cv7vDQxw_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EzY11VTx_sendMessage);
}

void Heavy_ChaffVerb::cMsg_tKZKAusT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_giTLcA7T, 0, m, &hTable_giTLcA7T_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Cs25OqnJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 16.364f, 0, m, &cBinop_D9V8Elwk_sendMessage);
}

void Heavy_ChaffVerb::cMsg_jC2Qh6ox_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_giTLcA7T, 0, m, &hTable_giTLcA7T_sendMessage);
}

void Heavy_ChaffVerb::cCast_EzY11VTx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_cv7vDQxw, 0, m, &cDelay_cv7vDQxw_sendMessage);
}

void Heavy_ChaffVerb::cMsg_UF7rC9le_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_TPHicpsP, 2, m, &cDelay_TPHicpsP_sendMessage);
}

void Heavy_ChaffVerb::cMsg_hv4oBJtn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_S9UN3mKO, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_ENmo1egN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tvDWHSJu, HV_BINOP_SUBTRACT, 0, m, &cBinop_tvDWHSJu_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Yzu20T5y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_SdzQWMWD_sendMessage);
}

void Heavy_ChaffVerb::cSystem_SdzQWMWD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_WiU9zmIi_sendMessage);
}

void Heavy_ChaffVerb::cVar_x8ezLMxf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xJKiF2Mo_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_Ncr2tMQH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Ncr2tMQH, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_zyJyZv6e, 0, m, &cDelay_zyJyZv6e_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_RbvJeJAQ, 0, m, &sTabread_RbvJeJAQ_sendMessage);
}

void Heavy_ChaffVerb::cDelay_zyJyZv6e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_zyJyZv6e, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_RbvJeJAQ, 0, m, &sTabread_RbvJeJAQ_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_zyJyZv6e, 0, m, &cDelay_zyJyZv6e_sendMessage);
}

void Heavy_ChaffVerb::sTabread_RbvJeJAQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_m2kFOFkK, HV_BINOP_SUBTRACT, 0, m, &cBinop_m2kFOFkK_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_gmQB5WDs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mRapKcO2, HV_BINOP_MAX, 0, m, &cBinop_mRapKcO2_sendMessage);
}

void Heavy_ChaffVerb::cBinop_WiU9zmIi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gmQB5WDs, HV_BINOP_MULTIPLY, 0, m, &cBinop_gmQB5WDs_sendMessage);
}

void Heavy_ChaffVerb::cBinop_tvDWHSJu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ex7c5EQY_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_RbvJeJAQ, 0, m, &sTabread_RbvJeJAQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IJQSbiC0_sendMessage);
}

void Heavy_ChaffVerb::cSystem_n0DdVSjc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_m2kFOFkK, HV_BINOP_SUBTRACT, 1, m, &cBinop_m2kFOFkK_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_zyJyZv6e, 2, m, &cDelay_zyJyZv6e_sendMessage);
}

void Heavy_ChaffVerb::cMsg_xJKiF2Mo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_n0DdVSjc_sendMessage);
}

void Heavy_ChaffVerb::cMsg_ex7c5EQY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Ncr2tMQH, 0, m, &cDelay_Ncr2tMQH_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_zyJyZv6e, 0, m, &cDelay_zyJyZv6e_sendMessage);
}

void Heavy_ChaffVerb::cMsg_rj7NI2Ao_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_mRapKcO2, HV_BINOP_MAX, 1, m, &cBinop_mRapKcO2_sendMessage);
}

void Heavy_ChaffVerb::cBinop_mRapKcO2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tvDWHSJu, HV_BINOP_SUBTRACT, 1, m, &cBinop_tvDWHSJu_sendMessage);
}

void Heavy_ChaffVerb::cCast_IJQSbiC0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Ncr2tMQH, 0, m, &cDelay_Ncr2tMQH_sendMessage);
}

void Heavy_ChaffVerb::cBinop_evhhOGQP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Ncr2tMQH, 2, m, &cDelay_Ncr2tMQH_sendMessage);
}

void Heavy_ChaffVerb::cBinop_m2kFOFkK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_evhhOGQP_sendMessage);
}

void Heavy_ChaffVerb::cCast_q9BNHCFg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_x8ezLMxf, 0, m, &cVar_x8ezLMxf_sendMessage);
  cMsg_Yzu20T5y_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_ENmo1egN, 0, m, &cTabhead_ENmo1egN_sendMessage);
}

void Heavy_ChaffVerb::cMsg_wPfBIMO5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_gb6y40FJ_sendMessage);
}

void Heavy_ChaffVerb::cSystem_gb6y40FJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_axDvTGal_sendMessage);
}

void Heavy_ChaffVerb::cDelay_tCCXrmvP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_tCCXrmvP, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_SNfCdIUL, 0, m, &cDelay_SNfCdIUL_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_tCCXrmvP, 0, m, &cDelay_tCCXrmvP_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_4QFm9txG, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_SNfCdIUL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_SNfCdIUL, m);
  cMsg_de3YdDjh_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_zjtj0cCt_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_QmeTf5w5_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_bSRFVHWX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_d1kgX8aD_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_q2orfTlk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6uXymsdb_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_tCCXrmvP, 2, m, &cDelay_tCCXrmvP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ed4lZA4L_sendMessage);
}

void Heavy_ChaffVerb::cMsg_d1kgX8aD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_q2orfTlk, 0, m, &hTable_q2orfTlk_sendMessage);
}

void Heavy_ChaffVerb::cBinop_axDvTGal_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 4.2546f, 0, m, &cBinop_bSRFVHWX_sendMessage);
}

void Heavy_ChaffVerb::cMsg_de3YdDjh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_q2orfTlk, 0, m, &hTable_q2orfTlk_sendMessage);
}

void Heavy_ChaffVerb::cCast_ed4lZA4L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_tCCXrmvP, 0, m, &cDelay_tCCXrmvP_sendMessage);
}

void Heavy_ChaffVerb::cMsg_6uXymsdb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_SNfCdIUL, 2, m, &cDelay_SNfCdIUL_sendMessage);
}

void Heavy_ChaffVerb::cMsg_QmeTf5w5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_4QFm9txG, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_8pBGksOt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tCHPttmq, HV_BINOP_SUBTRACT, 0, m, &cBinop_tCHPttmq_sendMessage);
}

void Heavy_ChaffVerb::cMsg_vNcG6shs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ldUj79bM_sendMessage);
}

void Heavy_ChaffVerb::cSystem_ldUj79bM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_bAGnyWVJ_sendMessage);
}

void Heavy_ChaffVerb::cVar_eHFgmnPJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RXCKO0DI_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_OM2ZTRfz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_OM2ZTRfz, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_rsbZTNnt, 0, m, &cDelay_rsbZTNnt_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_18WxEltQ, 0, m, &sTabread_18WxEltQ_sendMessage);
}

void Heavy_ChaffVerb::cDelay_rsbZTNnt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_rsbZTNnt, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_18WxEltQ, 0, m, &sTabread_18WxEltQ_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_rsbZTNnt, 0, m, &cDelay_rsbZTNnt_sendMessage);
}

void Heavy_ChaffVerb::sTabread_18WxEltQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_VahIToIg, HV_BINOP_SUBTRACT, 0, m, &cBinop_VahIToIg_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_r2pBmShc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RQ8AuKyl, HV_BINOP_MAX, 0, m, &cBinop_RQ8AuKyl_sendMessage);
}

void Heavy_ChaffVerb::cBinop_bAGnyWVJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_r2pBmShc, HV_BINOP_MULTIPLY, 0, m, &cBinop_r2pBmShc_sendMessage);
}

void Heavy_ChaffVerb::cBinop_tCHPttmq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_euG40Cbh_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_18WxEltQ, 0, m, &sTabread_18WxEltQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DXUi8pvU_sendMessage);
}

void Heavy_ChaffVerb::cSystem_oXpIXfUl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VahIToIg, HV_BINOP_SUBTRACT, 1, m, &cBinop_VahIToIg_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_rsbZTNnt, 2, m, &cDelay_rsbZTNnt_sendMessage);
}

void Heavy_ChaffVerb::cMsg_RXCKO0DI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_oXpIXfUl_sendMessage);
}

void Heavy_ChaffVerb::cMsg_euG40Cbh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_OM2ZTRfz, 0, m, &cDelay_OM2ZTRfz_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_rsbZTNnt, 0, m, &cDelay_rsbZTNnt_sendMessage);
}

void Heavy_ChaffVerb::cMsg_gPMDto43_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_RQ8AuKyl, HV_BINOP_MAX, 1, m, &cBinop_RQ8AuKyl_sendMessage);
}

void Heavy_ChaffVerb::cBinop_RQ8AuKyl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tCHPttmq, HV_BINOP_SUBTRACT, 1, m, &cBinop_tCHPttmq_sendMessage);
}

void Heavy_ChaffVerb::cCast_DXUi8pvU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_OM2ZTRfz, 0, m, &cDelay_OM2ZTRfz_sendMessage);
}

void Heavy_ChaffVerb::cBinop_8iIixZTF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_OM2ZTRfz, 2, m, &cDelay_OM2ZTRfz_sendMessage);
}

void Heavy_ChaffVerb::cBinop_VahIToIg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_8iIixZTF_sendMessage);
}

void Heavy_ChaffVerb::cCast_nHHoKq9o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_eHFgmnPJ, 0, m, &cVar_eHFgmnPJ_sendMessage);
  cMsg_vNcG6shs_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_8pBGksOt, 0, m, &cTabhead_8pBGksOt_sendMessage);
}

void Heavy_ChaffVerb::cMsg_jUDOk34I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_1HfhMS8K_sendMessage);
}

void Heavy_ChaffVerb::cSystem_1HfhMS8K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_n2zxn9mG_sendMessage);
}

void Heavy_ChaffVerb::cDelay_jGZDHNcM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_jGZDHNcM, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_HpuALlgz, 0, m, &cDelay_HpuALlgz_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_jGZDHNcM, 0, m, &cDelay_jGZDHNcM_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_ePBn4bHE, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_HpuALlgz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_HpuALlgz, m);
  cMsg_vozL0Yqr_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_l93prFrD_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_dT03uWvU_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_q5v6X8s0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3ESl0G20_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_qBB091qh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_S3pOMG1G_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_jGZDHNcM, 2, m, &cDelay_jGZDHNcM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ijPZnTf7_sendMessage);
}

void Heavy_ChaffVerb::cMsg_3ESl0G20_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_qBB091qh, 0, m, &hTable_qBB091qh_sendMessage);
}

void Heavy_ChaffVerb::cBinop_n2zxn9mG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 7.645f, 0, m, &cBinop_q5v6X8s0_sendMessage);
}

void Heavy_ChaffVerb::cMsg_vozL0Yqr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_qBB091qh, 0, m, &hTable_qBB091qh_sendMessage);
}

void Heavy_ChaffVerb::cCast_ijPZnTf7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_jGZDHNcM, 0, m, &cDelay_jGZDHNcM_sendMessage);
}

void Heavy_ChaffVerb::cMsg_S3pOMG1G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_HpuALlgz, 2, m, &cDelay_HpuALlgz_sendMessage);
}

void Heavy_ChaffVerb::cMsg_dT03uWvU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_ePBn4bHE, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_7iCibBZR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hrmhortT, HV_BINOP_SUBTRACT, 0, m, &cBinop_hrmhortT_sendMessage);
}

void Heavy_ChaffVerb::cMsg_SANNuDx6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_YcTGFcwA_sendMessage);
}

void Heavy_ChaffVerb::cSystem_YcTGFcwA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_WzseURxv_sendMessage);
}

void Heavy_ChaffVerb::cVar_NRBGibz3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_diiwCaJT_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_HhnCKYkD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_HhnCKYkD, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_e3Osx1DX, 0, m, &cDelay_e3Osx1DX_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_8xYydRsB, 0, m, &sTabread_8xYydRsB_sendMessage);
}

void Heavy_ChaffVerb::cDelay_e3Osx1DX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_e3Osx1DX, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_8xYydRsB, 0, m, &sTabread_8xYydRsB_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_e3Osx1DX, 0, m, &cDelay_e3Osx1DX_sendMessage);
}

void Heavy_ChaffVerb::sTabread_8xYydRsB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_WRhWegqg, HV_BINOP_SUBTRACT, 0, m, &cBinop_WRhWegqg_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_BYKvi91d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WnCx3UwD, HV_BINOP_MAX, 0, m, &cBinop_WnCx3UwD_sendMessage);
}

void Heavy_ChaffVerb::cBinop_WzseURxv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BYKvi91d, HV_BINOP_MULTIPLY, 0, m, &cBinop_BYKvi91d_sendMessage);
}

void Heavy_ChaffVerb::cBinop_hrmhortT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DoFGoz10_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_8xYydRsB, 0, m, &sTabread_8xYydRsB_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ocWD3zf9_sendMessage);
}

void Heavy_ChaffVerb::cSystem_fmjS5hX1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WRhWegqg, HV_BINOP_SUBTRACT, 1, m, &cBinop_WRhWegqg_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_e3Osx1DX, 2, m, &cDelay_e3Osx1DX_sendMessage);
}

void Heavy_ChaffVerb::cMsg_diiwCaJT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_fmjS5hX1_sendMessage);
}

void Heavy_ChaffVerb::cMsg_DoFGoz10_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_HhnCKYkD, 0, m, &cDelay_HhnCKYkD_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_e3Osx1DX, 0, m, &cDelay_e3Osx1DX_sendMessage);
}

void Heavy_ChaffVerb::cMsg_21TBb4XE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_WnCx3UwD, HV_BINOP_MAX, 1, m, &cBinop_WnCx3UwD_sendMessage);
}

void Heavy_ChaffVerb::cBinop_WnCx3UwD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hrmhortT, HV_BINOP_SUBTRACT, 1, m, &cBinop_hrmhortT_sendMessage);
}

void Heavy_ChaffVerb::cCast_ocWD3zf9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_HhnCKYkD, 0, m, &cDelay_HhnCKYkD_sendMessage);
}

void Heavy_ChaffVerb::cBinop_8VqzBlV3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_HhnCKYkD, 2, m, &cDelay_HhnCKYkD_sendMessage);
}

void Heavy_ChaffVerb::cBinop_WRhWegqg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_8VqzBlV3_sendMessage);
}

void Heavy_ChaffVerb::cCast_PgdjgLnF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_NRBGibz3, 0, m, &cVar_NRBGibz3_sendMessage);
  cMsg_SANNuDx6_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_7iCibBZR, 0, m, &cTabhead_7iCibBZR_sendMessage);
}

void Heavy_ChaffVerb::cVar_DUmfrq7l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_fXgFpsF0, 0, m, &cVar_fXgFpsF0_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_I0S6g0Uv, 0, m, &cVar_I0S6g0Uv_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_WhJY5Ixy, 0, m, &cVar_WhJY5Ixy_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_443M7CYE, 0, m, &cVar_443M7CYE_sendMessage);
}

void Heavy_ChaffVerb::cVar_KakEh7GG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.01f, 0, m, &cBinop_XgKgFAH9_sendMessage);
}

void Heavy_ChaffVerb::cPack_Ecxd4Btu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sLine_onMessage(_c, &Context(_c)->sLine_xbzsq2FY, 0, m, NULL);
}

void Heavy_ChaffVerb::cVar_I0S6g0Uv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TPMIZzat, HV_BINOP_MULTIPLY, 0, m, &cBinop_TPMIZzat_sendMessage);
}

void Heavy_ChaffVerb::cMsg_6C5P5xCG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ZymPdGan_sendMessage);
}

void Heavy_ChaffVerb::cSystem_ZymPdGan_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cjV4fTpX_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_TPMIZzat_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_7asygAML_sendMessage);
}

void Heavy_ChaffVerb::cBinop_wpmLQ66b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TPMIZzat, HV_BINOP_MULTIPLY, 1, m, &cBinop_TPMIZzat_sendMessage);
}

void Heavy_ChaffVerb::cMsg_cjV4fTpX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_wpmLQ66b_sendMessage);
}

void Heavy_ChaffVerb::cBinop_7asygAML_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_ofa3lR5W_sendMessage);
}

void Heavy_ChaffVerb::cBinop_ofa3lR5W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_PWHVUhum_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_O9mxsXez, m);
}

void Heavy_ChaffVerb::cBinop_PWHVUhum_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_WyRUF50p, m);
}

void Heavy_ChaffVerb::cVar_WhJY5Ixy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ynBwZ9kq, HV_BINOP_MULTIPLY, 0, m, &cBinop_ynBwZ9kq_sendMessage);
}

void Heavy_ChaffVerb::cMsg_AgV4N6ss_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_qV4scaHV_sendMessage);
}

void Heavy_ChaffVerb::cSystem_qV4scaHV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9EBVuWAa_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_ynBwZ9kq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_n67iGy0F_sendMessage);
}

void Heavy_ChaffVerb::cBinop_o7cLdUUo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ynBwZ9kq, HV_BINOP_MULTIPLY, 1, m, &cBinop_ynBwZ9kq_sendMessage);
}

void Heavy_ChaffVerb::cMsg_9EBVuWAa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_o7cLdUUo_sendMessage);
}

void Heavy_ChaffVerb::cBinop_n67iGy0F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_SONt1JdT_sendMessage);
}

void Heavy_ChaffVerb::cBinop_SONt1JdT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_Dw6wCyPV_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_1GKDkyD0, m);
}

void Heavy_ChaffVerb::cBinop_Dw6wCyPV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_VfAVIJM5, m);
}

void Heavy_ChaffVerb::cVar_443M7CYE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tyH9SQr1, HV_BINOP_MULTIPLY, 0, m, &cBinop_tyH9SQr1_sendMessage);
}

void Heavy_ChaffVerb::cMsg_v6M8SRTy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_VCmgDJjX_sendMessage);
}

void Heavy_ChaffVerb::cSystem_VCmgDJjX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WAT2rw6G_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_tyH9SQr1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_gLx4zd3K_sendMessage);
}

void Heavy_ChaffVerb::cBinop_7QEedLZC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tyH9SQr1, HV_BINOP_MULTIPLY, 1, m, &cBinop_tyH9SQr1_sendMessage);
}

void Heavy_ChaffVerb::cMsg_WAT2rw6G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_7QEedLZC_sendMessage);
}

void Heavy_ChaffVerb::cBinop_gLx4zd3K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_0Kfz8Yab_sendMessage);
}

void Heavy_ChaffVerb::cBinop_0Kfz8Yab_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_0XvY5e2o_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_Y5IbmkOV, m);
}

void Heavy_ChaffVerb::cBinop_0XvY5e2o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_LDkbbEZz, m);
}

void Heavy_ChaffVerb::cBinop_3WyssFfY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_p7zoaMGB, 0, m, &cPack_p7zoaMGB_sendMessage);
}

void Heavy_ChaffVerb::cMsg_zXqbnH9g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 3000.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_DUmfrq7l, 0, m, &cVar_DUmfrq7l_sendMessage);
}

void Heavy_ChaffVerb::cBinop_XgKgFAH9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_Ecxd4Btu, 0, m, &cPack_Ecxd4Btu_sendMessage);
}

void Heavy_ChaffVerb::cBinop_s7raUbIz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_fGt1YB7V, 0, m, &cPack_fGt1YB7V_sendMessage);
}

void Heavy_ChaffVerb::cSwitchcase_bVCvX3jb_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cMsg_TAHUgd8D_sendMessage(_c, 0, m);
      break;
    }
    case 0x7A5B032D: { // "stop"
      cMsg_TAHUgd8D_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_09o7bRE1_sendMessage);
      break;
    }
  }
}

void Heavy_ChaffVerb::cDelay_PytoHoQl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_PytoHoQl, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_PytoHoQl, 0, m, &cDelay_PytoHoQl_sendMessage);
  cSwitchcase_3Uv6Fd8p_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cCast_09o7bRE1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TAHUgd8D_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_PytoHoQl, 0, m, &cDelay_PytoHoQl_sendMessage);
  cSwitchcase_3Uv6Fd8p_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cMsg_MtJ556oz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Sjub8A7U_sendMessage);
}

void Heavy_ChaffVerb::cSystem_Sjub8A7U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_R36tzG9x_sendMessage);
}

void Heavy_ChaffVerb::cVar_485SeXnK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JYhN4ggm, HV_BINOP_MULTIPLY, 0, m, &cBinop_JYhN4ggm_sendMessage);
}

void Heavy_ChaffVerb::cMsg_TAHUgd8D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_PytoHoQl, 0, m, &cDelay_PytoHoQl_sendMessage);
}

void Heavy_ChaffVerb::cBinop_4FCgomZ8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_PytoHoQl, 2, m, &cDelay_PytoHoQl_sendMessage);
}

void Heavy_ChaffVerb::cBinop_R36tzG9x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JYhN4ggm, HV_BINOP_MULTIPLY, 1, m, &cBinop_JYhN4ggm_sendMessage);
}

void Heavy_ChaffVerb::cBinop_JYhN4ggm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_4FCgomZ8_sendMessage);
}

void Heavy_ChaffVerb::cVar_YX8v9oc9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MOD_UNIPOLAR, 628.0f, 0, m, &cBinop_IqgiXDWp_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 2.0f, 0, m, &cBinop_QBG7lttO_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_eqtUJfKh_sendMessage);
}

void Heavy_ChaffVerb::cVar_kry5TWIQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_xL8F6CSC_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_trJmItzA, 0, m, &cIf_trJmItzA_sendMessage);
}

void Heavy_ChaffVerb::cUnop_UeQhSCoe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5jsqlO45, HV_BINOP_MOD_UNIPOLAR, 1, m, &cBinop_5jsqlO45_sendMessage);
}

void Heavy_ChaffVerb::cUnop_Q7kEbitY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5jsqlO45, HV_BINOP_MOD_UNIPOLAR, 1, m, &cBinop_5jsqlO45_sendMessage);
}

void Heavy_ChaffVerb::cIf_trJmItzA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cUnop_onMessage(_c, HV_UNOP_CEIL, m, &cUnop_Q7kEbitY_sendMessage);
      break;
    }
    case 1: {
      cUnop_onMessage(_c, HV_UNOP_FLOOR, m, &cUnop_UeQhSCoe_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_xL8F6CSC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_trJmItzA, 1, m, &cIf_trJmItzA_sendMessage);
}

void Heavy_ChaffVerb::cMsg_doDkCyKy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_s30ZJBnu_sendMessage);
}

void Heavy_ChaffVerb::cSystem_s30ZJBnu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_0k3G5vMS_sendMessage);
}

void Heavy_ChaffVerb::cDelay_hU4llCfj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_hU4llCfj, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_4vJKZcYf, 0, m, &cDelay_4vJKZcYf_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_hU4llCfj, 0, m, &cDelay_hU4llCfj_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_azEBcTCe, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_4vJKZcYf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_4vJKZcYf, m);
  cMsg_CXrCaJE9_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_G5xmjrRS_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_JJLp2vYR_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_rXNsuM2R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_U4UQJChk_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_L7NJBGh6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5Ua3kl03_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_hU4llCfj, 2, m, &cDelay_hU4llCfj_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_iv27HzTc_sendMessage);
}

void Heavy_ChaffVerb::cMsg_U4UQJChk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_L7NJBGh6, 0, m, &hTable_L7NJBGh6_sendMessage);
}

void Heavy_ChaffVerb::cBinop_0k3G5vMS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 3000.0f, 0, m, &cBinop_rXNsuM2R_sendMessage);
}

void Heavy_ChaffVerb::cMsg_CXrCaJE9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_L7NJBGh6, 0, m, &hTable_L7NJBGh6_sendMessage);
}

void Heavy_ChaffVerb::cCast_iv27HzTc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_hU4llCfj, 0, m, &cDelay_hU4llCfj_sendMessage);
}

void Heavy_ChaffVerb::cMsg_5Ua3kl03_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_4vJKZcYf, 2, m, &cDelay_4vJKZcYf_sendMessage);
}

void Heavy_ChaffVerb::cMsg_JJLp2vYR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_azEBcTCe, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_ORVbPI8R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qDzC6Krq, HV_BINOP_SUBTRACT, 0, m, &cBinop_qDzC6Krq_sendMessage);
}

void Heavy_ChaffVerb::cMsg_ihbDag0L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Nawmi6zL_sendMessage);
}

void Heavy_ChaffVerb::cSystem_Nawmi6zL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_GrAJSgMd_sendMessage);
}

void Heavy_ChaffVerb::cVar_7OCxbr6W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cf4QxIdb_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_pEeHxv08_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_pEeHxv08, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_FpqaTGLC, 0, m, &cDelay_FpqaTGLC_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_B4m31igs, 0, m, &sTabread_B4m31igs_sendMessage);
}

void Heavy_ChaffVerb::cDelay_FpqaTGLC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_FpqaTGLC, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_B4m31igs, 0, m, &sTabread_B4m31igs_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_FpqaTGLC, 0, m, &cDelay_FpqaTGLC_sendMessage);
}

void Heavy_ChaffVerb::sTabread_B4m31igs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_b5P4Ts8H, HV_BINOP_SUBTRACT, 0, m, &cBinop_b5P4Ts8H_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_zh5WTNM6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HjPKrX3s, HV_BINOP_MAX, 0, m, &cBinop_HjPKrX3s_sendMessage);
}

void Heavy_ChaffVerb::cBinop_GrAJSgMd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zh5WTNM6, HV_BINOP_MULTIPLY, 0, m, &cBinop_zh5WTNM6_sendMessage);
}

void Heavy_ChaffVerb::cBinop_qDzC6Krq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NM1r7aSk_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_B4m31igs, 0, m, &sTabread_B4m31igs_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0l7PpWNS_sendMessage);
}

void Heavy_ChaffVerb::cSystem_kAKt8Diy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_b5P4Ts8H, HV_BINOP_SUBTRACT, 1, m, &cBinop_b5P4Ts8H_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_FpqaTGLC, 2, m, &cDelay_FpqaTGLC_sendMessage);
}

void Heavy_ChaffVerb::cMsg_cf4QxIdb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_kAKt8Diy_sendMessage);
}

void Heavy_ChaffVerb::cMsg_NM1r7aSk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_pEeHxv08, 0, m, &cDelay_pEeHxv08_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_FpqaTGLC, 0, m, &cDelay_FpqaTGLC_sendMessage);
}

void Heavy_ChaffVerb::cMsg_hqS1yMdV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_HjPKrX3s, HV_BINOP_MAX, 1, m, &cBinop_HjPKrX3s_sendMessage);
}

void Heavy_ChaffVerb::cBinop_HjPKrX3s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qDzC6Krq, HV_BINOP_SUBTRACT, 1, m, &cBinop_qDzC6Krq_sendMessage);
}

void Heavy_ChaffVerb::cCast_0l7PpWNS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_pEeHxv08, 0, m, &cDelay_pEeHxv08_sendMessage);
}

void Heavy_ChaffVerb::cBinop_o0CfbAvY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_pEeHxv08, 2, m, &cDelay_pEeHxv08_sendMessage);
}

void Heavy_ChaffVerb::cBinop_b5P4Ts8H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_o0CfbAvY_sendMessage);
}

void Heavy_ChaffVerb::cCast_ZgmWcJdu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7OCxbr6W, 0, m, &cVar_7OCxbr6W_sendMessage);
  cMsg_ihbDag0L_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_ORVbPI8R, 0, m, &cTabhead_ORVbPI8R_sendMessage);
}

void Heavy_ChaffVerb::cSwitchcase_tDMwIUUD_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vPr8ukoN_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cCast_vPr8ukoN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rMll3i7d_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cVar_X83T25BI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_atyEqK7y, HV_BINOP_ADD, 0, m, &cBinop_atyEqK7y_sendMessage);
}

void Heavy_ChaffVerb::cSwitchcase_Es0BJF1C_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kfuKpzkF_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cCast_kfuKpzkF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GDIld0MK_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cVar_sRuotCL2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_M1h1VBfE_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HfoP4l8b_sendMessage);
}

void Heavy_ChaffVerb::cVar_IdRgGlRI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_k1paVRUq, 0, m, &cVar_k1paVRUq_sendMessage);
}

void Heavy_ChaffVerb::cVar_k1paVRUq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WeSqvwLv, HV_BINOP_ADD, 0, m, &cBinop_WeSqvwLv_sendMessage);
}

void Heavy_ChaffVerb::cVar_Q7PM3wci_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DbC5XjBe, HV_BINOP_ADD, 0, m, &cBinop_DbC5XjBe_sendMessage);
}

void Heavy_ChaffVerb::cVar_6Iemn6Eg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_CMDkMiDP_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_eO2pemkq, 0, m, &cIf_eO2pemkq_sendMessage);
}

void Heavy_ChaffVerb::cUnop_MdNwQ2hg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DbC5XjBe, HV_BINOP_ADD, 1, m, &cBinop_DbC5XjBe_sendMessage);
}

void Heavy_ChaffVerb::cUnop_aEZ4X5r6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DbC5XjBe, HV_BINOP_ADD, 1, m, &cBinop_DbC5XjBe_sendMessage);
}

void Heavy_ChaffVerb::cIf_eO2pemkq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cUnop_onMessage(_c, HV_UNOP_CEIL, m, &cUnop_aEZ4X5r6_sendMessage);
      break;
    }
    case 1: {
      cUnop_onMessage(_c, HV_UNOP_FLOOR, m, &cUnop_MdNwQ2hg_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_CMDkMiDP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_eO2pemkq, 1, m, &cIf_eO2pemkq_sendMessage);
}

void Heavy_ChaffVerb::cVar_Z4iHosQS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_45f1Jn7a_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_qGNxcImY, 0, m, &cIf_qGNxcImY_sendMessage);
}

void Heavy_ChaffVerb::cUnop_qXq8zmJU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_3aYMi7xj_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cUnop_O3az2NHy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_3aYMi7xj_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cIf_qGNxcImY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cUnop_onMessage(_c, HV_UNOP_CEIL, m, &cUnop_O3az2NHy_sendMessage);
      break;
    }
    case 1: {
      cUnop_onMessage(_c, HV_UNOP_FLOOR, m, &cUnop_qXq8zmJU_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_45f1Jn7a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qGNxcImY, 1, m, &cIf_qGNxcImY_sendMessage);
}

void Heavy_ChaffVerb::cSwitchcase_3aYMi7xj_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_MliDOj2o, 0, m, &cSlice_MliDOj2o_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_mmI4o2q2, 0, m, &cSlice_mmI4o2q2_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_izrbMMxX_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fUil099c_sendMessage);
      break;
    }
  }
}

void Heavy_ChaffVerb::cSlice_MliDOj2o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_XvKnZ57B, 0, m, &cVar_XvKnZ57B_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_XvKnZ57B, 0, m, &cVar_XvKnZ57B_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cSlice_mmI4o2q2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_yLSXdD7y, HV_BINOP_NEQ, 1, m, &cBinop_yLSXdD7y_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_XvKnZ57B, 1, m, &cVar_XvKnZ57B_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_yLSXdD7y, HV_BINOP_NEQ, 1, m, &cBinop_yLSXdD7y_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_XvKnZ57B, 1, m, &cVar_XvKnZ57B_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cVar_XvKnZ57B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_i1q4hBb7_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_iayNteuh_sendMessage);
}

void Heavy_ChaffVerb::cIf_ozGrrXCJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_78rP002x_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ow1lb5IY_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cCast_ow1lb5IY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_XvKnZ57B, 0, m, &cVar_XvKnZ57B_sendMessage);
}

void Heavy_ChaffVerb::cCast_78rP002x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yLSXdD7y, HV_BINOP_NEQ, 1, m, &cBinop_yLSXdD7y_sendMessage);
}

void Heavy_ChaffVerb::cBinop_yLSXdD7y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ozGrrXCJ, 1, m, &cIf_ozGrrXCJ_sendMessage);
}

void Heavy_ChaffVerb::cCast_izrbMMxX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yLSXdD7y, HV_BINOP_NEQ, 0, m, &cBinop_yLSXdD7y_sendMessage);
}

void Heavy_ChaffVerb::cCast_fUil099c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ozGrrXCJ, 0, m, &cIf_ozGrrXCJ_sendMessage);
}

void Heavy_ChaffVerb::cIf_JpYoQq4j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_IdRgGlRI, 0, m, &cVar_IdRgGlRI_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cIf_8fUIzGTP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cIf_onMessage(_c, &Context(_c)->cIf_JpYoQq4j, 0, m, &cIf_JpYoQq4j_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cIf_Mr1CnmgC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cIf_onMessage(_c, &Context(_c)->cIf_JpYoQq4j, 0, m, &cIf_JpYoQq4j_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cIf_IoVsv4au_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cIf_onMessage(_c, &Context(_c)->cIf_JpYoQq4j, 0, m, &cIf_JpYoQq4j_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cIf_biX90F8G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_sRuotCL2, 0, m, &cVar_sRuotCL2_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cCast_8vYIfa9T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Q7PM3wci, 0, m, &cVar_Q7PM3wci_sendMessage);
}

void Heavy_ChaffVerb::cMsg_uhGsp3iS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_8fUIzGTP, 1, m, &cIf_8fUIzGTP_sendMessage);
}

void Heavy_ChaffVerb::cMsg_WuzidbFT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_IoVsv4au, 1, m, &cIf_IoVsv4au_sendMessage);
}

void Heavy_ChaffVerb::cMsg_YBM00PNN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_8fUIzGTP, 1, m, &cIf_8fUIzGTP_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_Mr1CnmgC, 1, m, &cIf_Mr1CnmgC_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_IoVsv4au, 1, m, &cIf_IoVsv4au_sendMessage);
}

void Heavy_ChaffVerb::cBinop_ALJgt6ZO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_X83T25BI, 0, m, &cVar_X83T25BI_sendMessage);
}

void Heavy_ChaffVerb::cBinop_uewWTS4x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_ALJgt6ZO_sendMessage);
}

void Heavy_ChaffVerb::cMsg_GDIld0MK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_sRuotCL2, 0, m, &cVar_sRuotCL2_sendMessage);
}

void Heavy_ChaffVerb::cBinop_5jsqlO45_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_X3uy4Ndk, HV_BINOP_MULTIPLY, 0, m, &cBinop_X3uy4Ndk_sendMessage);
}

void Heavy_ChaffVerb::cBinop_eqtUJfKh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5jsqlO45, HV_BINOP_MOD_UNIPOLAR, 0, m, &cBinop_5jsqlO45_sendMessage);
}

void Heavy_ChaffVerb::cMsg_X8DgBo2I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_Mr1CnmgC, 1, m, &cIf_Mr1CnmgC_sendMessage);
}

void Heavy_ChaffVerb::cBinop_DbC5XjBe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1klMG5XJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TZMHz2p8_sendMessage);
}

void Heavy_ChaffVerb::cBinop_LRITNHXs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ODdHrkvx, 0, m, &cVar_ODdHrkvx_sendMessage);
}

void Heavy_ChaffVerb::cCast_1klMG5XJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LRITNHXs, HV_BINOP_ADD, 1, m, &cBinop_LRITNHXs_sendMessage);
}

void Heavy_ChaffVerb::cCast_TZMHz2p8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_IdRgGlRI, 0, m, &cVar_IdRgGlRI_sendMessage);
}

void Heavy_ChaffVerb::cCast_i1q4hBb7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YBM00PNN_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cCast_iayNteuh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_zZCwqSRV_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cBinop_VTLhVkPR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1eWsxQMS, 0, m, &cVar_1eWsxQMS_sendMessage);
}

void Heavy_ChaffVerb::cBinop_X3uy4Ndk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Mr1CnmgC, 0, m, &cIf_Mr1CnmgC_sendMessage);
}

void Heavy_ChaffVerb::cBinop_DaI1qNjE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_IoVsv4au, 0, m, &cIf_IoVsv4au_sendMessage);
}

void Heavy_ChaffVerb::cBinop_qnsdXAqn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_HWqVJgI6_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 3.1415f, 0, m, &cBinop_DaI1qNjE_sendMessage);
}

void Heavy_ChaffVerb::cBinop_IqgiXDWp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 314.0f, 0, m, &cBinop_HJq4D2QH_sendMessage);
}

void Heavy_ChaffVerb::cBinop_HJq4D2QH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_qnsdXAqn_sendMessage);
}

void Heavy_ChaffVerb::cBinop_QBG7lttO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_YX8v9oc9, 1, m, &cVar_YX8v9oc9_sendMessage);
}

void Heavy_ChaffVerb::cBinop_u9mfNsck_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_PIbvHXd6, 0, m, &cVar_PIbvHXd6_sendMessage);
}

void Heavy_ChaffVerb::cBinop_rHV1HAsm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_485SeXnK, 0, m, &cVar_485SeXnK_sendMessage);
}

void Heavy_ChaffVerb::cMsg_rMll3i7d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_IdRgGlRI, 0, m, &cVar_IdRgGlRI_sendMessage);
}

void Heavy_ChaffVerb::cBinop_atyEqK7y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DzqH979z, HV_BINOP_MULTIPLY, 0, m, &cBinop_DzqH979z_sendMessage);
}

void Heavy_ChaffVerb::cBinop_DzqH979z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_biX90F8G, 0, m, &cIf_biX90F8G_sendMessage);
}

void Heavy_ChaffVerb::cBinop_fAyPuy9P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LRITNHXs, HV_BINOP_ADD, 0, m, &cBinop_LRITNHXs_sendMessage);
}

void Heavy_ChaffVerb::cCast_M1h1VBfE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fAyPuy9P, HV_BINOP_ADD, 1, m, &cBinop_fAyPuy9P_sendMessage);
}

void Heavy_ChaffVerb::cCast_HfoP4l8b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_IdRgGlRI, 0, m, &cVar_IdRgGlRI_sendMessage);
}

void Heavy_ChaffVerb::cCast_Ii54qSf5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_tDMwIUUD_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cCast_z2S3mScA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JpYoQq4j, 1, m, &cIf_JpYoQq4j_sendMessage);
}

void Heavy_ChaffVerb::cCast_FpQhaDOV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_X83T25BI, 0, m, &cVar_X83T25BI_sendMessage);
}

void Heavy_ChaffVerb::cCast_TMrwG9de_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DzqH979z, HV_BINOP_MULTIPLY, 1, m, &cBinop_DzqH979z_sendMessage);
}

void Heavy_ChaffVerb::cCast_eB7TSKfs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Es0BJF1C_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cCast_eg1neooh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_biX90F8G, 1, m, &cIf_biX90F8G_sendMessage);
}

void Heavy_ChaffVerb::cCast_4wh2I2c8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_atyEqK7y, HV_BINOP_ADD, 1, m, &cBinop_atyEqK7y_sendMessage);
}

void Heavy_ChaffVerb::cCast_fimQLYPK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_X83T25BI, 0, m, &cVar_X83T25BI_sendMessage);
}

void Heavy_ChaffVerb::cBinop_uXtukGZ5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fAyPuy9P, HV_BINOP_ADD, 0, m, &cBinop_fAyPuy9P_sendMessage);
}

void Heavy_ChaffVerb::cBinop_WeSqvwLv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uXtukGZ5, HV_BINOP_MULTIPLY, 0, m, &cBinop_uXtukGZ5_sendMessage);
}

void Heavy_ChaffVerb::cCast_RK6xBttC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uXtukGZ5, HV_BINOP_MULTIPLY, 1, m, &cBinop_uXtukGZ5_sendMessage);
}

void Heavy_ChaffVerb::cCast_0Pf3STwn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_IdRgGlRI, 0, m, &cVar_IdRgGlRI_sendMessage);
}

void Heavy_ChaffVerb::cCast_7pqAWpju_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WeSqvwLv, HV_BINOP_ADD, 1, m, &cBinop_WeSqvwLv_sendMessage);
}

void Heavy_ChaffVerb::cCast_XCuPz071_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_IdRgGlRI, 0, m, &cVar_IdRgGlRI_sendMessage);
}

void Heavy_ChaffVerb::cMsg_DzvyO2Xr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_i1q4hBb7_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_iayNteuh_sendMessage);
}

void Heavy_ChaffVerb::cReceive_GMfRmNf2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5mTy0jtd_sendMessage(_c, 0, m);
  cMsg_d17bD3vA_sendMessage(_c, 0, m);
  cMsg_dth16pqW_sendMessage(_c, 0, m);
  cMsg_mCRTHbrl_sendMessage(_c, 0, m);
  cMsg_wPfBIMO5_sendMessage(_c, 0, m);
  cMsg_jUDOk34I_sendMessage(_c, 0, m);
  cMsg_kMeJbgVr_sendMessage(_c, 0, m);
  cMsg_nEKxjg0E_sendMessage(_c, 0, m);
  cMsg_A5Xq5rVo_sendMessage(_c, 0, m);
  cMsg_MeztCBe7_sendMessage(_c, 0, m);
  cMsg_eX4RuWyx_sendMessage(_c, 0, m);
  cMsg_qiX0MTKJ_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_fXgFpsF0, 0, m, &cVar_fXgFpsF0_sendMessage);
  cMsg_6C5P5xCG_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_I0S6g0Uv, 0, m, &cVar_I0S6g0Uv_sendMessage);
  cMsg_AgV4N6ss_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_WhJY5Ixy, 0, m, &cVar_WhJY5Ixy_sendMessage);
  cMsg_v6M8SRTy_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_443M7CYE, 0, m, &cVar_443M7CYE_sendMessage);
  cMsg_Aejd6rNt_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_jKakNvpE, 0, m, &cVar_jKakNvpE_sendMessage);
  cMsg_5VbXoVqO_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_PIbvHXd6, 0, m, &cVar_PIbvHXd6_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_oHnXd3cT, 0, m, &cVar_oHnXd3cT_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_1eWsxQMS, 0, m, &cVar_1eWsxQMS_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_YCMr5MlE, 0, m, &cVar_YCMr5MlE_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_oFdrLCII, 0, m, &cVar_oFdrLCII_sendMessage);
  cMsg_MtJ556oz_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_485SeXnK, 0, m, &cVar_485SeXnK_sendMessage);
  cMsg_doDkCyKy_sendMessage(_c, 0, m);
  cSwitchcase_Tcoz9cTr_onMessage(_c, NULL, 0, m, NULL);
  cMsg_rMll3i7d_sendMessage(_c, 0, m);
  cMsg_DzvyO2Xr_sendMessage(_c, 0, m);
  cMsg_GDIld0MK_sendMessage(_c, 0, m);
  cSwitchcase_bVCvX3jb_onMessage(_c, NULL, 0, m, NULL);
  cVar_onMessage(_c, &Context(_c)->cVar_PKCpMu1q, 0, m, &cVar_PKCpMu1q_sendMessage);
  cMsg_nBDibG1z_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_kfCPvAJ6, 0, m, &cVar_kfCPvAJ6_sendMessage);
  cMsg_7ZHOAvsJ_sendMessage(_c, 0, m);
  cMsg_js9ocMJ9_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_mo2tx1bc, 0, m, &cVar_mo2tx1bc_sendMessage);
  cMsg_0P5vgpcP_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_RyvU3PWU, 0, m, &cTabhead_RyvU3PWU_sendMessage);
  cMsg_bTVrJWjP_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_0mzy8eyX, 0, m, &cVar_0mzy8eyX_sendMessage);
  cMsg_rAC3e481_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_zSf3h4nV, 0, m, &cTabhead_zSf3h4nV_sendMessage);
  cMsg_DesWvglX_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_69EXG7nV, 0, m, &cVar_69EXG7nV_sendMessage);
  cMsg_GYMUQXhZ_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_vf8MpW5m, 0, m, &cTabhead_vf8MpW5m_sendMessage);
  cMsg_y8f3BIVC_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_8HGBrpHJ, 0, m, &cVar_8HGBrpHJ_sendMessage);
  cMsg_UOcZqbQ5_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_5US86sJf, 0, m, &cTabhead_5US86sJf_sendMessage);
  cMsg_0QI0Hm3F_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_SVESKeA9, 0, m, &cVar_SVESKeA9_sendMessage);
  cMsg_mzR6UhGa_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_vZBCvVpQ, 0, m, &cTabhead_vZBCvVpQ_sendMessage);
  cMsg_CCWFnRev_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_pKC0yOrJ, 0, m, &cVar_pKC0yOrJ_sendMessage);
  cMsg_r4UnVSPQ_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_InAl9VQU, 0, m, &cTabhead_InAl9VQU_sendMessage);
  cMsg_RnDDQVCT_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_y7ej96da, 0, m, &cVar_y7ej96da_sendMessage);
  cMsg_bLOhHLEk_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_8W3uz42X, 0, m, &cTabhead_8W3uz42X_sendMessage);
  cMsg_rj7NI2Ao_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_x8ezLMxf, 0, m, &cVar_x8ezLMxf_sendMessage);
  cMsg_Yzu20T5y_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_ENmo1egN, 0, m, &cTabhead_ENmo1egN_sendMessage);
  cMsg_gPMDto43_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_eHFgmnPJ, 0, m, &cVar_eHFgmnPJ_sendMessage);
  cMsg_vNcG6shs_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_8pBGksOt, 0, m, &cTabhead_8pBGksOt_sendMessage);
  cMsg_21TBb4XE_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_NRBGibz3, 0, m, &cVar_NRBGibz3_sendMessage);
  cMsg_SANNuDx6_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_7iCibBZR, 0, m, &cTabhead_7iCibBZR_sendMessage);
  cMsg_hqS1yMdV_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_7OCxbr6W, 0, m, &cVar_7OCxbr6W_sendMessage);
  cMsg_ihbDag0L_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_ORVbPI8R, 0, m, &cTabhead_ORVbPI8R_sendMessage);
}

void Heavy_ChaffVerb::cReceive_x4w58j7N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 157.0f, 0, m, &cBinop_u9mfNsck_sendMessage);
}

void Heavy_ChaffVerb::cReceive_Yq18nDfq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Z4iHosQS, 0, m, &cVar_Z4iHosQS_sendMessage);
}

void Heavy_ChaffVerb::cReceive_66BxQk6g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_kry5TWIQ, 0, m, &cVar_kry5TWIQ_sendMessage);
}

void Heavy_ChaffVerb::cReceive_EhJQp0f0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_X3uy4Ndk, HV_BINOP_MULTIPLY, 1, m, &cBinop_X3uy4Ndk_sendMessage);
}

void Heavy_ChaffVerb::cReceive_WVF18ach_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7pqAWpju_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XCuPz071_sendMessage);
}

void Heavy_ChaffVerb::cReceive_xXFBhsqU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RK6xBttC_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0Pf3STwn_sendMessage);
}

void Heavy_ChaffVerb::cReceive_qOout72y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Q7PM3wci, 0, m, &cVar_Q7PM3wci_sendMessage);
}

void Heavy_ChaffVerb::cReceive_WQaP177n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8vYIfa9T_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_6Iemn6Eg, 0, m, &cVar_6Iemn6Eg_sendMessage);
}

void Heavy_ChaffVerb::cReceive_mMpD8sR2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 157.0f, 0, m, &cBinop_rHV1HAsm_sendMessage);
}

void Heavy_ChaffVerb::cReceive_tYZtLglG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4wh2I2c8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fimQLYPK_sendMessage);
}

void Heavy_ChaffVerb::cReceive_86arlxyv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TMrwG9de_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FpQhaDOV_sendMessage);
}

void Heavy_ChaffVerb::cReceive_Jn3t7dGT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_eg1neooh_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_eB7TSKfs_sendMessage);
}

void Heavy_ChaffVerb::cReceive_GfgBm8zT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_tUXS7tFD, m);
}

void Heavy_ChaffVerb::cReceive_Qht5EUN4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_hmfLznrA, m);
}

void Heavy_ChaffVerb::cReceive_XIR4osph_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_oHnXd3cT, 0, m, &cVar_oHnXd3cT_sendMessage);
}

void Heavy_ChaffVerb::cReceive_2U88Decy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 100.0f, 0, m, &cBinop_VTLhVkPR_sendMessage);
}

void Heavy_ChaffVerb::cReceive_gEFiBOlR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xefN2xWb, 0, m, &cVar_xefN2xWb_sendMessage);
}

void Heavy_ChaffVerb::cReceive_l5kzDwJD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_aNZ5WOMY, 0, m, &cVar_aNZ5WOMY_sendMessage);
}

void Heavy_ChaffVerb::cReceive_qUoUOHPz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_jKakNvpE, 0, m, &cVar_jKakNvpE_sendMessage);
}

void Heavy_ChaffVerb::cReceive_kZFs9edU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_WvtFyz98, m);
}

void Heavy_ChaffVerb::cReceive_m65WsHUJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_XnggL2Sl, m);
}

void Heavy_ChaffVerb::cReceive_O94JcZ2g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zh5WTNM6, HV_BINOP_MULTIPLY, 1, m, &cBinop_zh5WTNM6_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZgmWcJdu_sendMessage);
}

void Heavy_ChaffVerb::cReceive_R27U671w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_z2S3mScA_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Ii54qSf5_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_ChaffVerb::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8, Bf9, Bf10, Bf11, Bf12, Bf13, Bf14;
  hv_bufferi_t Bi0, Bi1;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_phasor_k_f(&sPhasor_afzQn89y, VOf(Bf0));
    __hv_var_k_f(VOf(Bf1), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_floor_f(VIf(Bf2), VOf(Bf1));
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_abs_f(VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f);
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f);
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_mul_f(VIf(Bf2), VIf(Bf2), VOf(Bf1));
    __hv_mul_f(VIf(Bf2), VIf(Bf1), VOf(Bf3));
    __hv_mul_f(VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf4), 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f);
    __hv_var_k_f(VOf(Bf5), 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f);
    __hv_mul_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_sub_f(VIf(Bf2), VIf(Bf5), VOf(Bf5));
    __hv_fma_f(VIf(Bf1), VIf(Bf4), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_Kkad90Ga, VOf(Bf4));
    __hv_line_f(&sLine_t9TMQyqE, VOf(Bf1));
    __hv_fma_f(VIf(Bf0), VIf(Bf4), VIf(Bf1), VOf(Bf2));
    __hv_tabhead_f(&sTabhead_4pkvc85T, VOf(Bf3));
    __hv_var_k_f_r(VOf(Bf6), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf3), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_WVacaQ7w, VOf(Bf3));
    __hv_mul_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_EiZDkHzY, VOf(Bf2));
    __hv_min_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_zero_f(VOf(Bf3));
    __hv_max_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_sub_f(VIf(Bf6), VIf(Bf3), VOf(Bf3));
    __hv_floor_f(VIf(Bf3), VOf(Bf6));
    __hv_varread_f(&sVarf_p3JLKD9J, VOf(Bf2));
    __hv_zero_f(VOf(Bf7));
    __hv_lt_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_and_f(VIf(Bf2), VIf(Bf7), VOf(Bf7));
    __hv_add_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_cast_fi(VIf(Bf7), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_VeSwpv8V, VIi(Bi1), VOf(Bf7));
    __hv_tabread_if(&sTabread_iQtvS8pZ, VIi(Bi0), VOf(Bf2));
    __hv_sub_f(VIf(Bf7), VIf(Bf2), VOf(Bf7));
    __hv_sub_f(VIf(Bf3), VIf(Bf6), VOf(Bf6));
    __hv_fma_f(VIf(Bf7), VIf(Bf6), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf6), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_add_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_floor_f(VIf(Bf6), VOf(Bf0));
    __hv_sub_f(VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf6), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf7), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_mul_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_floor_f(VIf(Bf7), VOf(Bf6));
    __hv_sub_f(VIf(Bf7), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf7), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_abs_f(VIf(Bf7), VOf(Bf7));
    __hv_var_k_f(VOf(Bf6), 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f);
    __hv_sub_f(VIf(Bf7), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf7), 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f);
    __hv_mul_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_mul_f(VIf(Bf7), VIf(Bf7), VOf(Bf6));
    __hv_mul_f(VIf(Bf7), VIf(Bf6), VOf(Bf3));
    __hv_mul_f(VIf(Bf3), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf8), 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f);
    __hv_var_k_f(VOf(Bf9), 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f);
    __hv_mul_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_sub_f(VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf6), VIf(Bf8), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf0), VIf(Bf4), VIf(Bf1), VOf(Bf1));
    __hv_tabhead_f(&sTabhead_ekQ8ud6x, VOf(Bf4));
    __hv_var_k_f_r(VOf(Bf0), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf4), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_2BIj1rbB, VOf(Bf4));
    __hv_mul_f(VIf(Bf1), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_fYGKIVhv, VOf(Bf1));
    __hv_min_f(VIf(Bf4), VIf(Bf1), VOf(Bf1));
    __hv_zero_f(VOf(Bf4));
    __hv_max_f(VIf(Bf1), VIf(Bf4), VOf(Bf4));
    __hv_sub_f(VIf(Bf0), VIf(Bf4), VOf(Bf4));
    __hv_floor_f(VIf(Bf4), VOf(Bf0));
    __hv_varread_f(&sVarf_X8LW4HZy, VOf(Bf1));
    __hv_zero_f(VOf(Bf8));
    __hv_lt_f(VIf(Bf0), VIf(Bf8), VOf(Bf8));
    __hv_and_f(VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_add_f(VIf(Bf0), VIf(Bf8), VOf(Bf8));
    __hv_cast_fi(VIf(Bf8), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_LSTIa4QR, VIi(Bi1), VOf(Bf8));
    __hv_tabread_if(&sTabread_q3rxNhgH, VIi(Bi0), VOf(Bf1));
    __hv_sub_f(VIf(Bf8), VIf(Bf1), VOf(Bf8));
    __hv_sub_f(VIf(Bf4), VIf(Bf0), VOf(Bf0));
    __hv_fma_f(VIf(Bf8), VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_mul_f(VIf(Bf9), VIf(Bf1), VOf(Bf1));
    __hv_fma_f(VIf(Bf5), VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_tabwrite_f(&sTabwrite_QRkkhrJc, VIf(I0));
    __hv_varread_f(&sVarf_bJyc68z9, VOf(Bf2));
    __hv_rpole_f(&sRPole_8t6iTKa4, VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_jut503ns, VIf(Bf2), VOf(Bf5));
    __hv_mul_f(VIf(Bf5), VIf(Bf1), VOf(Bf1));
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_a2y9uWxd, VOf(Bf2));
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_WvtFyz98, VOf(Bf1));
    __hv_tabread_f(&sTabread_B4m31igs, VOf(Bf5));
    __hv_varread_f(&sVarf_XnggL2Sl, VOf(Bf9));
    __hv_mul_f(VIf(Bf5), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf2), VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_tabwrite_f(&sTabwrite_azEBcTCe, VIf(Bf9));
    __hv_varread_f(&sVarf_hmfLznrA, VOf(Bf9));
    __hv_fma_f(VIf(I0), VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_tabread_f(&sTabread_7WDI4aPT, VOf(Bf9));
    __hv_varread_f(&sVarf_BcSoIBbs, VOf(Bf1));
    __hv_mul_f(VIf(Bf9), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_J6Ap7flw, VOf(Bf2));
    __hv_rpole_f(&sRPole_fNTUQ2jn, VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_sub_f(VIf(Bf2), VIf(Bf9), VOf(Bf2));
    __hv_line_f(&sLine_xbzsq2FY, VOf(Bf1));
    __hv_fma_f(VIf(Bf2), VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_B8tHs58F, VOf(Bf2));
    __hv_tabread_f(&sTabread_5vBrt5Lt, VOf(Bf0));
    __hv_add_f(VIf(Bf5), VIf(Bf0), VOf(Bf8));
    __hv_tabread_f(&sTabread_1Kl3wrmP, VOf(Bf4));
    __hv_add_f(VIf(Bf8), VIf(Bf4), VOf(Bf6));
    __hv_tabread_f(&sTabread_cLcPVf2T, VOf(Bf7));
    __hv_add_f(VIf(Bf6), VIf(Bf7), VOf(Bf3));
    __hv_tabread_f(&sTabread_RbvJeJAQ, VOf(Bf10));
    __hv_add_f(VIf(Bf3), VIf(Bf10), VOf(Bf11));
    __hv_tabread_f(&sTabread_8xYydRsB, VOf(Bf12));
    __hv_add_f(VIf(Bf11), VIf(Bf12), VOf(Bf13));
    __hv_tabread_f(&sTabread_18WxEltQ, VOf(Bf14));
    __hv_tabwrite_f(&sTabwrite_bQeLtBe0, VIf(Bf5));
    __hv_sub_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_tabwrite_f(&sTabwrite_G4XvBQ0b, VIf(Bf0));
    __hv_sub_f(VIf(Bf8), VIf(Bf4), VOf(Bf4));
    __hv_tabwrite_f(&sTabwrite_WHZaySni, VIf(Bf4));
    __hv_sub_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_tabwrite_f(&sTabwrite_S9UN3mKO, VIf(Bf7));
    __hv_sub_f(VIf(Bf11), VIf(Bf12), VOf(Bf12));
    __hv_tabwrite_f(&sTabwrite_4QFm9txG, VIf(Bf12));
    __hv_sub_f(VIf(Bf3), VIf(Bf10), VOf(Bf10));
    __hv_tabwrite_f(&sTabwrite_ePBn4bHE, VIf(Bf10));
    __hv_fma_f(VIf(Bf9), VIf(Bf2), VIf(Bf13), VOf(Bf13));
    __hv_tabread_f(&sTabread_gnHu58Jr, VOf(Bf9));
    __hv_varread_f(&sVarf_O9mxsXez, VOf(Bf10));
    __hv_mul_f(VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_WyRUF50p, VOf(Bf3));
    __hv_rpole_f(&sRPole_i9JFecmT, VIf(Bf10), VIf(Bf3), VOf(Bf3));
    __hv_sub_f(VIf(Bf3), VIf(Bf9), VOf(Bf3));
    __hv_fma_f(VIf(Bf3), VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf9), VIf(Bf2), VIf(Bf14), VOf(Bf14));
    __hv_add_f(VIf(Bf13), VIf(Bf14), VOf(Bf9));
    __hv_tabread_f(&sTabread_ahU3pB3H, VOf(Bf3));
    __hv_varread_f(&sVarf_1GKDkyD0, VOf(Bf10));
    __hv_mul_f(VIf(Bf3), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_VfAVIJM5, VOf(Bf12));
    __hv_rpole_f(&sRPole_73OZHrfu, VIf(Bf10), VIf(Bf12), VOf(Bf12));
    __hv_sub_f(VIf(Bf12), VIf(Bf3), VOf(Bf12));
    __hv_fma_f(VIf(Bf12), VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_mul_f(VIf(Bf3), VIf(Bf2), VOf(Bf3));
    __hv_tabread_f(&sTabread_yqQ1pdWX, VOf(Bf12));
    __hv_varread_f(&sVarf_Y5IbmkOV, VOf(Bf10));
    __hv_mul_f(VIf(Bf12), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_LDkbbEZz, VOf(Bf11));
    __hv_rpole_f(&sRPole_geUrmdX7, VIf(Bf10), VIf(Bf11), VOf(Bf11));
    __hv_sub_f(VIf(Bf11), VIf(Bf12), VOf(Bf11));
    __hv_fma_f(VIf(Bf11), VIf(Bf1), VIf(Bf12), VOf(Bf12));
    __hv_mul_f(VIf(Bf12), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf3), VIf(Bf2), VOf(Bf12));
    __hv_add_f(VIf(Bf9), VIf(Bf12), VOf(Bf1));
    __hv_tabwrite_f(&sTabwrite_5dVdSzOB, VIf(Bf1));
    __hv_sub_f(VIf(Bf13), VIf(Bf14), VOf(Bf1));
    __hv_sub_f(VIf(Bf3), VIf(Bf2), VOf(Bf11));
    __hv_add_f(VIf(Bf1), VIf(Bf11), VOf(Bf10));
    __hv_tabwrite_f(&sTabwrite_c2DjzXtG, VIf(Bf10));
    __hv_sub_f(VIf(Bf9), VIf(Bf12), VOf(Bf12));
    __hv_tabwrite_f(&sTabwrite_jnLSUggd, VIf(Bf12));
    __hv_sub_f(VIf(Bf1), VIf(Bf11), VOf(Bf11));
    __hv_tabwrite_f(&sTabwrite_ol5QyNWW, VIf(Bf11));
    __hv_line_f(&sLine_ix9qJEoG, VOf(Bf11));
    __hv_mul_f(VIf(Bf13), VIf(Bf11), VOf(Bf13));
    __hv_mul_f(VIf(Bf14), VIf(Bf11), VOf(Bf14));
    __hv_mul_f(VIf(Bf3), VIf(Bf11), VOf(Bf3));
    __hv_mul_f(VIf(Bf2), VIf(Bf11), VOf(Bf11));
    __hv_varread_f(&sVarf_tUXS7tFD, VOf(Bf2));
    __hv_mul_f(VIf(I0), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf13), VIf(Bf2), VOf(Bf13));
    __hv_add_f(VIf(Bf13), VIf(O0), VOf(O0));
    __hv_add_f(VIf(Bf14), VIf(Bf3), VOf(Bf3));
    __hv_add_f(VIf(Bf3), VIf(Bf11), VOf(Bf11));
    __hv_add_f(VIf(Bf11), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf2), VIf(O1), VOf(O1));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_ChaffVerb::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 1 channel(s)
  float **const bIn = &inputBuffers;

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_ChaffVerb::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 1 channel(s), uninterleave
  float *const bIn = inputBuffers;

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
